*XDFLT
      SUBROUTINE XDFLT(LDS)
C
C     LATEST REVISION  -  03/15/90  (JRD)
C
C     ROUTINE TO TEST THE TIME SERIES DIGITAL FILTERING AND
C     COMPLEX DEMODULATION ROUTINES.
C
C     SERIES Y IS THE WOLF SUNSPOT DATA FROM 1700 TO 1960 AS
C     TABULATED BY WALDMEIER
C
C     WRITTEN BY  -  JANET R. DONALDSON
C                    STATISTICAL ENGINEERING DEVISION
C                    NATIONAL BUREAU OF STANDARDS, BOULDER, COLORADO
C
C     CREATION DATE  -  NOVEMBER 26, 1980
C
C
C  VARIABLE DECLARATIONS
C
C  SCALAR ARGUMENTS
      INTEGER
     +   LDS
C
C  SCALARS IN COMMON
      INTEGER
     +   IERR
C
C  ARRAYS IN COMMON
      DOUBLE PRECISION DSTAK(12)
C
C  LOCAL SCALARS
      DOUBLE PRECISION
     +   FC,FMAX,FMIN,YFMISS,YMISS
      INTEGER
     +   I,IAR,IPRT,ITEST,K,LDSTAK,LPHI,N,NF,NFAC,NPRT,NYF,NYS
C
C  LOCAL ARRAYS
      DOUBLE PRECISION
     +   FREQ(101),GAIN(101),HHP(50),HLP(50),PHAS(300),PHI(50),Y(300),
     +   YF(300),YS(300)
      INTEGER
     +   IOD(10),ND(10)
C
C  EXTERNAL SUBROUTINES
      EXTERNAL ARFLT,DIF,DIFC,DIFM,DIFMC,GFARF,GFARFS,GFSLF,GFSLFS,
     +   HIPASS,HPCOEF,IPRINT,LOPASS,LPCOEF,MAFLT,SAMPLE,SLFLT
C
C  COMMON BLOCKS
      COMMON /CSTAK/DSTAK
      COMMON /ERRCHK/IERR
C
C     VARIABLE DEFINITIONS (ALPHABETICALLY)
C
C     DOUBLE PRECISION DSTAK(12)
C        THE DOUBLE PRECISION VERSION OF THE /CSTAK/ WORK AREA.
C     DOUBLE PRECISION FC
C        THE CUTOFF FREQUENCY USED FOR THE LOW PASS FILTER.
C     DOUBLE PRECISION FMAX, FMIN
C        THE MINIMUM AND MAXIMUM FREQUENCY FOR WHICH THE GAIN
C        FUNCTION IS TO BE ESTIMATED.
C     DOUBLE PRECISION FREQ(101)
C        THE VECTOR OF FREQUENCIES AT WHICH THE GAIN FUNCTION
C        HAS BEEN ESTIMATED.
C     DOUBLE PRECISION GAIN(101)
C        THE VECTOR IN WHICH THE GAIN FUNCTION ESTIMATES ARE
C        STORED.
C     DOUBLE PRECISION HHP(50)
C        THE ARRAY IN WHICH THE -IDEAL- HIGH PASS FILTER COEFFICIENTS
C        WILL BE RETURNED.
C     DOUBLE PRECISION HLP(50)
C        THE ARRAY IN WHICH THE INPUT LOW PASS FILTER COEFFICIENTS
C        ARE STORED.
C     INTEGER I
C        AN INDEXING VARIABLE.
C     INTEGER IAR
C        THE NUMBER OF FILTER COEFFICIENTS.
C     INTEGER IERR
C        THE INTEGER VALUE RETURNED BY THIS ROUTINE DESIGNATING
C        WHETHER ANY ERRORS WERE DETECTED IN THE PARAMETER LIST.
C        IF IERR .EQ. 0, NO ERRORS WERE DETECTED.
C        IF IERR .EQ. 1, ERRORS HAVE BEEN DETECTED.
C     INTEGER IOD(10)
C        THE ORDER OF EACH OF THE DIFFERENCE FACTORS.
C     INTEGER IPRT
C        THE UNIT NUMBER USED FOR OUTPUT.
C     INTEGER ITEST
C        THE NUMBER OF THE TEST BEING PERFORMED
C     INTEGER K
C        THE NUMBER OF TERMS IN THE SYMETRIC LINEAR FILTER.
C     INTEGER LDS, LDSTAK
C        THE LENGTH OF THE ARRAY DSTAK.
C     INTEGER LPHI
C        THE LENGTH OF THE VECTOR PHI.
C     INTEGER N
C        THE NUMBER OF OBSERVATIONS IN THE INPUT SERIES.
C     INTEGER ND(10)
C        THE ARRAY CONTAINING THE NUMBER OF TIMES THE DIFFERENCE
C        FACTORS ARE TO BE APPLIED.
C     INTEGER NFAC
C        THE NUMBER OF DIFFERENCE FACTORS.
C     INTEGER NF
C        THE NUMBER OF FREQUENCIES AT WHICH THE GAIN FUNCTION
C        IS TO BE ESTIMATED.
C     INTEGER NPRT
C        A CODE USED TO SPECIFY THE TYPE OF PLOT, WHERE IF
C        NPRT = 0 THE PLOT IS SUPPRESSED
C        NPRT = 1 THE PLOT IS DECIBELS/LINEAR
C        NPRT = 2 THE PLOT IS LOG/LINEAR
C     INTEGER NYF
C        THE NUMBER OF VALUES IN THE FILTERED SERIES.
C     INTEGER NYS
C        THE NUMBER OF VALUES IN THE SAMPLED SERIES.
C     DOUBLE PRECISION PHAS(300)
C        THE ARRAY IN WHICH THE PRIMARY PHASE ESTIMATES ARE RETURNED.
C     DOUBLE PRECISION PHI(50)
C        THE VECTOR CONTAINING THE FILTER COEFFICIENTS.
C     DOUBLE PRECISION Y(300)
C        THE VECTOR CONTAINING THE OBSERVED TIME SERIES.
C     DOUBLE PRECISION YF(300)
C        THE VECTOR IN WHICH THE FILTERED SERIES IS RETURNED.
C     DOUBLE PRECISION YFMISS
C        THE MISSING VALUE CODE USED IN THE FILTERED SERIES.
C     DOUBLE PRECISION YMISS
C        THE MISSING VALUE CODE USED IN THE INPUT TIME SERIES.
C     DOUBLE PRECISION YS(300)
C        THE ARRAY CONTAINING THE SAMPLED SERIES.
C
      DATA   Y(  1),  Y(  2),  Y(  3),  Y(  4),  Y(  5),  Y(  6)
     +    /     5.0D0, 11.0D0, 16.0D0, 23.0D0, 36.0D0, 58.0D0/
      DATA   Y(  7),  Y(  8),  Y(  9),  Y( 10),  Y( 11),  Y( 12)
     +    /    29.0D0, 20.0D0, 10.0D0,  8.0D0,  3.0D0,  0.0D0/
      DATA   Y( 13),  Y( 14),  Y( 15),  Y( 16),  Y( 17),  Y( 18)
     +    /     0.0D0, 2.0D0, 11.0D0, 27.0D0, 47.0D0, 63.0D0/
      DATA   Y( 19),  Y( 20),  Y( 21),  Y( 22),  Y( 23),  Y( 24)
     +    /    60.0D0, 39.0D0, 28.0D0, 26.0D0, 22.0D0, 11.0D0/
      DATA   Y( 25),  Y( 26),  Y( 27),  Y( 28),  Y( 29),  Y( 30)
     +    /    21.0D0, 40.0D0, 78.0D0,122.0D0,103.0D0, 73.0D0/
      DATA   Y( 31),  Y( 32),  Y( 33),  Y( 34),  Y( 35),  Y( 36)
     +    /    47.0D0, 35.0D0, 11.0D0,  5.0D0, 16.0D0, 34.0D0/
      DATA   Y( 37),  Y( 38),  Y( 39),  Y( 40),  Y( 41),  Y( 42)
     +    /    70.0D0, 81.0D0,111.0D0,101.0D0, 73.0D0, 40.0D0/
      DATA   Y( 43),  Y( 44),  Y( 45),  Y( 46),  Y( 47),  Y( 48)
     +    /    20.0D0, 16.0D0,  5.0D0, 11.0D0, 22.0D0, 40.0D0/
      DATA   Y( 49),  Y( 50),  Y( 51),  Y( 52),  Y( 53),  Y( 54)
     +    /    60.0D0, 80.9D0, 83.4D0, 47.7D0, 47.8D0, 30.7D0/
      DATA   Y( 55),  Y( 56),  Y( 57),  Y( 58),  Y( 59),  Y( 60)
     +    /    12.2D0,  9.6D0, 10.2D0, 32.4D0, 47.6D0, 54.0D0/
      DATA   Y( 61),  Y( 62),  Y( 63),  Y( 64),  Y( 65),  Y( 66)
     +    /    62.9D0, 85.9D0, 61.2D0, 45.1D0, 36.4D0, 20.9D0/
      DATA   Y( 67),  Y( 68),  Y( 69),  Y( 70),  Y( 71),  Y( 72)
     +    /    11.4D0, 37.8D0, 69.8D0,106.1D0,100.8D0, 81.6D0/
      DATA   Y( 73),  Y( 74),  Y( 75),  Y( 76),  Y( 77),  Y( 78)
     +    /    66.5D0, 34.8D0, 30.6D0,  7.0D0, 19.8D0, 92.5D0/
      DATA   Y( 79),  Y( 80),  Y( 81),  Y( 82),  Y( 83),  Y( 84)
     +    /   154.4D0,125.9D0, 84.8D0, 68.1D0, 38.5D0, 22.8D0/
      DATA   Y( 85),  Y( 86),  Y( 87),  Y( 88),  Y( 89),  Y( 90)
     +    /    10.2D0, 24.1D0, 82.9D0,132.0D0,130.9D0,118.1D0/
      DATA   Y( 91),  Y( 92),  Y( 93),  Y( 94),  Y( 95),  Y( 96)
     +    /    89.9D0, 66.6D0, 60.0D0, 46.9D0, 41.0D0, 21.3D0/
      DATA   Y( 97),  Y( 98),  Y( 99),  Y(100),  Y(101),  Y(102)
     +    /    16.0D0,  6.4D0,  4.1D0,  6.8D0, 14.5D0, 34.0D0/
      DATA   Y(103),  Y(104),  Y(105),  Y(106),  Y(107),  Y(108)
     +    /    45.0D0, 43.1D0, 47.5D0, 42.2D0, 28.1D0, 10.1D0/
      DATA   Y(109),  Y(110),  Y(111),  Y(112),  Y(113),  Y(114)
     +    /     8.1D0,  2.5D0,  0.0D0,  1.4D0,  5.0D0, 12.2D0/
      DATA   Y(115),  Y(116),  Y(117),  Y(118),  Y(119),  Y(120)
     +    /    13.9D0, 35.4D0, 45.8D0, 41.1D0, 30.1D0, 23.9D0/
      DATA   Y(121),  Y(122),  Y(123),  Y(124),  Y(125),  Y(126)
     +    /    15.6D0,  6.6D0,  4.0D0,  1.8D0,  8.5D0, 16.6D0/
      DATA   Y(127),  Y(128),  Y(129),  Y(130),  Y(131),  Y(132)
     +    /    36.3D0, 49.6D0, 64.2D0, 67.0D0, 70.9D0, 47.8D0/
      DATA   Y(133),  Y(134),  Y(135),  Y(136),  Y(137),  Y(138)
     +    /    27.5D0,  8.5D0, 13.2D0, 56.9D0,121.5D0,138.3D0/
      DATA   Y(139),  Y(140),  Y(141),  Y(142),  Y(143),  Y(144)
     +    /   103.2D0, 85.7D0, 64.6D0, 36.7D0, 24.2D0, 10.7D0/
      DATA   Y(145),  Y(146),  Y(147),  Y(148),  Y(149),  Y(150)
     +    /    15.0D0, 40.1D0, 61.5D0, 98.5D0,124.7D0, 96.3D0/
      DATA   Y(151),  Y(152),  Y(153),  Y(154),  Y(155),  Y(156)
     +    /    66.6D0, 64.5D0, 54.1D0, 39.0D0, 20.6D0,  6.7D0/
      DATA   Y(157),  Y(158),  Y(159),  Y(160),  Y(161),  Y(162)
     +    /     4.3D0, 22.7D0, 54.8D0, 93.8D0, 95.8D0, 77.2D0/
      DATA   Y(163),  Y(164),  Y(165),  Y(166),  Y(167),  Y(168)
     +    /    59.1D0, 44.0D0, 47.0D0, 30.5D0, 16.3D0,  7.3D0/
      DATA   Y(169),  Y(170),  Y(171),  Y(172),  Y(173),  Y(174)
     +    /    37.6D0, 74.0D0,139.0D0,111.2D0,101.6D0, 66.2D0/
      DATA   Y(175),  Y(176),  Y(177),  Y(178),  Y(179),  Y(180)
     +    /    44.7D0, 17.0D0, 11.3D0, 12.4D0,  3.4D0,  6.0D0/
      DATA   Y(181),  Y(182),  Y(183),  Y(184),  Y(185),  Y(186)
     +    /    32.3D0, 54.3D0, 59.7D0, 63.7D0, 63.5D0, 52.2D0/
      DATA   Y(187),  Y(188),  Y(189),  Y(190),  Y(191),  Y(192)
     +    /    25.4D0, 13.1D0,  6.8D0,  6.3D0,  7.1D0, 35.6D0/
      DATA   Y(193),  Y(194),  Y(195),  Y(196),  Y(197),  Y(198)
     +    /    73.0D0, 85.1D0, 78.0D0, 64.0D0, 41.8D0, 26.2D0/
      DATA   Y(199),  Y(200),  Y(201),  Y(202),  Y(203),  Y(204)
     +    /    26.7D0, 12.1D0,  9.5D0,  2.7D0,  5.0D0, 24.4D0/
      DATA   Y(205),  Y(206),  Y(207),  Y(208),  Y(209),  Y(210)
     +    /    42.0D0, 63.5D0, 53.8D0, 62.0D0, 48.5D0, 43.9D0/
      DATA   Y(211),  Y(212),  Y(213),  Y(214),  Y(215),  Y(216)
     +    /    18.6D0,  5.7D0,  3.6D0,  1.4D0,  9.6D0, 47.4D0/
      DATA   Y(217),  Y(218),  Y(219),  Y(220),  Y(221),  Y(222)
     +    /    57.1D0,103.9D0, 80.6D0, 63.6D0, 37.6D0, 26.1D0/
      DATA   Y(223),  Y(224),  Y(225),  Y(226),  Y(227),  Y(228)
     +    /    14.2D0,  5.8D0, 16.7D0, 44.3D0, 63.9D0, 69.0D0/
      DATA   Y(229),  Y(230),  Y(231),  Y(232),  Y(233),  Y(234)
     +    /    77.8D0, 64.9D0, 35.7D0, 21.2D0, 11.1D0,  5.7D0/
      DATA   Y(235),  Y(236),  Y(237),  Y(238),  Y(239),  Y(240)
     +    /     8.7D0, 36.1D0, 79.7D0,114.4D0,109.6D0, 88.8D0/
      DATA   Y(241),  Y(242),  Y(243),  Y(244),  Y(245),  Y(246)
     +    /    67.8D0, 47.5D0, 30.6D0, 16.3D0,  9.6D0, 33.2D0/
      DATA   Y(247),  Y(248),  Y(249),  Y(250),  Y(251),  Y(252)
     +    /    92.6D0,151.6D0,136.3D0,134.7D0, 83.9D0, 69.4D0/
      DATA   Y(253),  Y(254),  Y(255),  Y(256),  Y(257),  Y(258)
     +    /    31.5D0, 13.9D0,  4.4D0, 38.0D0,141.7D0,190.2D0/
      DATA   Y(259),  Y(260),  Y(261)
     +    /   184.8D0,159.0D0,112.3D0/
C
      CALL IPRINT(IPRT)
      ITEST = 1
      LDSTAK = LDS
C
      N = 261
      NPRT = 2
      FC = 1.0D0/22.0D0
      NF = 101
      FMIN = 0.0D0
      FMAX = 0.2D0
      LPHI = 50
      NFAC = 1
      ND(1) = 1
      IOD(1) = 1
      IAR = 1
      PHI(1) = 0.6D0
      K = 41
      YMISS = 11.0D0
C
C     TEST OF LPCOEF
C
   10 WRITE (IPRT, 1001)
      CALL LPCOEF (FC, K, HLP)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM LPCOEF
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (HLP(I), I = 1, K)
C
C     TEST OF LOPASS
C
      WRITE (IPRT, 1007)
      CALL LOPASS (Y, N, FC, K, HLP, YF, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM LOPASS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (HLP(I), I = 1, K)
        WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
      END IF
C
C     TEST OF HIPASS
C
      WRITE (IPRT, 1008)
      CALL HIPASS (Y, N, FC, K, HHP, YF, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM HIPASS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (HHP(I), I = 1, K)
        WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
      END IF
C
C     TEST OF HPCOEF
C
   20 WRITE (IPRT, 1003)
      CALL HPCOEF (HLP, K, HHP)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM HPCOEF
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (HHP(I), I = 1, K)
C
C     TEST OF MAFLT
C
      WRITE (IPRT, 1020)
      CALL MAFLT (Y, N, K, YF, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM MAFLT
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
C
C     TEST OF SLFLT
C
      WRITE (IPRT, 1005)
      CALL SLFLT (Y, N, K, HLP, YF, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM SLFLT
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
C
C     TEST OF SAMPLE
C
      WRITE (IPRT, 1006)
      CALL SAMPLE (YF, N, K, YS, NYS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM SAMPLE
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (YF(I), I = 1, NYS)
C
C     TEST OF ARFLT
C
      WRITE (IPRT, 1009)
      CALL ARFLT (Y, N,  IAR, PHI, YF, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM ARFLT
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
C
C     TEST OF DIF
C
      WRITE (IPRT, 1015)
      CALL DIF (Y, N, YF, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM DIF
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
C
C     TEST OF DIFM
C
      WRITE (IPRT, 1018)
      CALL DIFM (Y, YMISS, N, YF, YFMISS, NYF)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM DIFM
C
      IF (IERR.EQ.0) THEN
         WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
         WRITE (IPRT, 1004) YFMISS
      END IF
C
C     TEST OF GFSLF
C
      WRITE (IPRT, 1011)
      CALL GFSLF (HLP, K)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF GFARF
C
      WRITE (IPRT, 1013)
      CALL GFARF (PHI, IAR)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF DIFC
C
   30 WRITE (IPRT, 1010)
      CALL DIFC (Y, N, NFAC, ND, IOD, IAR, PHI, LPHI, YF, NYF, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM DIFC
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (PHI(I), I = 1, K)
        WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
      END IF
C
C     TEST OF DIFMC
C
      WRITE (IPRT, 1019)
      CALL DIFMC (Y, YMISS, N, NFAC, ND, IOD, IAR, PHI, LPHI, YF,
     +   YFMISS, NYF, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM DIFMC
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (PHI(I), I = 1, K)
        WRITE (IPRT, 1004) (YF(I), I = 1, NYF)
        WRITE (IPRT, 1004) YFMISS
      END IF
C
C     TEST OF GFSLFS
C
      WRITE (IPRT, 1012)
      CALL GFSLFS (HLP, K, NF, FMIN, FMAX, GAIN, FREQ, NPRT, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM GFSLFS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (GAIN(I), I = 1, NF)
        WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
      END IF
C
C     TEST OF GFARFS
C
      WRITE (IPRT, 1014)
      CALL GFARFS (PHI, IAR, NF, FMIN, FMAX, GAIN, PHAS, FREQ, NPRT,
     +   LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM GFARFS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (GAIN(I), I = 1, NF)
        WRITE (IPRT, 1004) (PHAS(I), I = 1, NF)
        WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
      END IF
C
      GO TO (100, 200, 300, 400), ITEST
C
C     TEST SPECIAL CASES
C
  100 ITEST = ITEST + 1
C
C     TEST OF GFSLFS
C
      FMIN = 0.4D0
      FMAX = 0.1D0
      NPRT = 1
      WRITE (IPRT, 1012)
      CALL GFSLFS (HLP, K, NF, FMIN, FMAX, GAIN, FREQ, NPRT, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM GFSLFS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (GAIN(I), I = 1, NF)
        WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
      END IF
C
C     TEST OF GFARFS
C
      NPRT = -1
      WRITE (IPRT, 1014)
      CALL GFARFS (PHI, IAR, NF, FMIN, FMAX, GAIN, PHAS, FREQ, NPRT,
     +   LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT STORAGE FROM GFARFS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (GAIN(I), I = 1, NF)
        WRITE (IPRT, 1004) (PHAS(I), I = 1, NF)
        WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
      END IF
C
C     TEST MINIMUM PROBLEM SIZE
C
      N = 3
      K = 1
      NPRT = -1
      IAR = 1
      NF = 1
      GO TO 20
C
C     TEST ERROR CONDITIONS
C
  200 ITEST = ITEST + 1
      N = -5
      FC = 1.0D0
      NF = 0
      LPHI = 0
      NFAC = 1
      ND(1) = -1
      IOD(1) = -1
      IAR = 0
      K = -1
      GO TO 10
C
C     TEST LDSTAK
C
  300 ITEST = ITEST + 1
      N = 261
      NPRT = 2
      FC = 1.0D0/22.0D0
      NF = 101
      FMIN = 0.0D0
      FMAX = 0.2D0
      LPHI = 50
      NFAC = 1
      ND(1) = 1
      IOD(1) = 1
      IAR = 1
      PHI(1) = 0.6D0
      K = 41
      YMISS = 11.0D0
      LDSTAK = 0
      GO TO 30
C
  400 RETURN
C
C     FORMAT STATEMENTS
C
 1001 FORMAT ('1', 14HTEST OF LPCOEF)
 1002 FORMAT (/' IERR IS ', I5)
 1003 FORMAT ('1', 14HTEST OF HPCOEF)
 1004 FORMAT (10E10.3)
 1005 FORMAT ('1', 13HTEST OF SLFLT)
 1006 FORMAT ('1', 14HTEST OF SAMPLE)
 1007 FORMAT ('1', 14HTEST OF LOPASS)
 1008 FORMAT ('1', 14HTEST OF HIPASS)
 1009 FORMAT ('1', 13HTEST OF ARFLT)
 1010 FORMAT ('1', 12HTEST OF DIFC)
 1011 FORMAT ('1', 13HTEST OF GFSLF)
 1012 FORMAT ('1', 14HTEST OF GFSLFS)
 1013 FORMAT ('1', 13HTEST OF GFARF)
 1014 FORMAT ('1', 14HTEST OF GFARFS)
 1015 FORMAT ('1', 11HTEST OF DIF)
 1018 FORMAT ('1', 12HTEST OF DIFM)
 1019 FORMAT ('1', 13HTEST OF DIFMC)
 1020 FORMAT ('1', 13HTEST OF MAFLT)
C
      END
