*XPGM
      SUBROUTINE XPGM(LDSTAK)
C
C     LATEST REVISION  -  03/15/90  (JRD)
C
C     ROUTINE TO TEST THE TIME SERIES PERIODOGRAM AND TIME SERIES
C     UTILITY SUBROUTINES
C
C     SERIES Y IS THE FIRST 50 VALUES OF THE SERIES LISTED ON PAGE
C     318 OF JENKINS AND WATTS.  THE SPECTRUM OF THIS SERIES IS SHOWN
C     FOR VARIOUS BANDWIDTH ON PAGE 270 OF JENKINS AND WATTS.
C
C     SERIES Z IS THE WOLF SUNSPOT NUMBERS FROM 1700 TO 1960 AS
C     TABULATED BY WALDMEIER.  THE RAW AND SMOOTHED PERIODOGRAMS OF
C     TAPERED SERIES ARE SHOWN ON PAGES 95 AND 176, RESPECTIVELY, OF
C     BLOOMFIELD.
C
C     WRITTEN BY - JANET R. DONALDSON
C                  STATISTICAL ENGINEERING DIVISION
C                  NATIONAL BUREAU OF STANDARDS, BOULDER, COLORADO
C
C     CREATION DATE  -  DECEMBER 2, 1985
C
C
C  VARIABLE DECLARATIONS
C
C  SCALAR ARGUMENTS
      INTEGER
     +   LDSTAK
C
C  SCALARS IN COMMON
      INTEGER
     +   IERR
C
C  ARRAYS IN COMMON
      DOUBLE PRECISION DSTAK(12)
C
C  LOCAL SCALARS
      DOUBLE PRECISION
     +   TAPERP
      INTEGER
     +   I,IEXTND,IPRT,ITEST,LAB,LFREQ,LPER,LPERI,LZFFT,NF,NFFT,NK,
     +   NPRT,NTEMP,NY,NZ
C
C  LOCAL ARRAYS
      DOUBLE PRECISION
     +   AB(600),FREQ(300),PER(300),PERF(300),PERI(300),Y(150),
     +   YFFT(400),Z(275),ZFFT(600),ZT(275)
      INTEGER
     +   K(10)
C
C  EXTERNAL SUBROUTINES
      EXTERNAL CENTER,FFTLEN,FFTR,IPGM,IPGMP,IPGMPS,IPGMS,IPRINT,MDFLT,
     +   PGM,PGMS,PPL,DCOPY,TAPER
C
C  COMMON BLOCKS
      COMMON /CSTAK/DSTAK
      COMMON /ERRCHK/IERR
C
C     VARIABLE DEFINITIONS (ALPHABETICALLY)
C
C     DOUBLE PRECISION AB(600)
C        THE VECTOR OF THE NF REAL AND IMAGINARY COMPONENTS OF THE
C        FOURIER COEFFICIENTS.
C     DOUBLE PRECISION DSTAK(12)
C        THE DOUBLE PRECISION VERSION OF THE /CSTAK/ WORK AREA.
C     DOUBLE PRECISION FREQ(300)
C        THE VECTOR OF FREQUENCIES AT WHICH THE SPECTRUM IS COMPUTED.
C     INTEGER I
C        AN INDEX VARIABLE
C     INTEGER IERR
C        THE INTEGER VALUE RETURNED BY THIS ROUTINE DESIGNATING
C        WHETHER ANY ERRORS WERE DETECTED IN THE PARAMETER LIST
C        IF IERR .EQ. 0, NO ERRORS WERE DETECTED
C        IF IERR .EQ. 1, ERRORS HAVE BEEN DETECTED
C     INTEGER IEXTND
C        THE INDICATOR VARIABLE USED TO DESIGNATE WHETHER ZERO
C        (IEXTND .EQ. 0) OR THE SERIES MEAN (IEXTND .NE. 0) IS TO BE
C        USED TO EXTEND THE SERIES.
C     INTEGER IPRT
C        THE LOGICAL UNIT USED FOR PRINTED OUTPUT.
C     INTEGER ITEST
C        THE NUMBER OF THE TEST SET BEING PERFORMED
C     INTEGER K(10)
C        THE VECTOR OF THE MODIFIED DANIEL FILTER LENGTHS.
C     INTEGER LAB
C        THE LENGTH OF THE VECTOR AB.
C     INTEGER LDSTAK
C        THE LENGTH OF THE VECTOR DSTAK IN COMMON CSTAK.
C     INTEGER LFREQ
C        THE LENGTH OF THE VECTOR FREQ.
C     INTEGER LPER
C        THE LENGTH OF THE VECTOR PER.
C     INTEGER LPERI
C        THE LENGTH OF THE VECTOR PERI.
C     INTEGER LZFFT
C        THE LENGTH OF THE VECTORS YFFT AND ZFFT, RESPECTIVELY..
C     INTEGER NF
C        THE NUMBER OF FREQUENCIES AT WHICH THE SPECTRUM IS
C        TO BE COMPUTED.
C     INTEGER NFFT
C        THE EXTENDED SERIES LENGTH.
C     INTEGER NK
C        THE NUMBER OF MODIFIED DANIEL FILTERS TO BE APPLIED.
C     INTEGER NPRT
C        THE VARIABLE CONTROLING PRINTED OUTPUT, WHERE
C        FOR THE PERIODOGRAM ROUTINES
C        IF NPRT .LE. -2, THE OUTPUT CONSISTS OF A PAGE PLOT OF THE
C                         PERIODOGRAM ON A LOG-LINEAR SCALE,
C        IF NPRT .EQ. -1, THE OUTPUT CONSISTS OF A PAGE PLOT OF THE
C                         PERIODOGRAM IN DECIBELS ON A LINEAR SCALE,
C        IF NPRT .EQ.  0, THE OUTPUT IS SUPPRESSED,
C        IF NPRT .EQ.  1, THE OUTPUT CONSISTS OF A VERTICAL PLOT OF THE
C                         PERIODOGRAM IN DECIBELS ON A LINEAR SCALE.
C        IF NPRT .GE.  2, THE OUTPUT CONSISTS OF A VERTICAL PLOT OF THE
C                         PERIODOGRAM ON A LOG-LINEAR SCALE,
C        AND FOR THE INTEGRATED PERIODOGRAM ROUTINES
C        IF NPRT .EQ.  0, THE OUTPUT IS SUPPRESSED,
C        IF NPRT .NE.  0, THE OUTPUT CONSISTS OF A PAGE PLOT OF THE
C                         INTEGRATED PERIODOGRAM
C     INTEGER NTEMP
C        A TEMPORARY STORAGE LOCATION
C     INTEGER NY
C        THE NUMBER OF OBSERVATIONS IN THE SERIES Y.
C     INTEGER NZ
C        THE NUMBER OF OBSERVATIONS IN THE SERIES Z.
C     DOUBLE PRECISION PER(300)
C        THE SERIES PERIODOGRAM.
C     DOUBLE PRECISION PERF(300)
C        THE FILTERED (SMOOTHED) PERIODOGRAM.
C     DOUBLE PRECISION PERI(300)
C        THE SERIES INTEGRATED PERIODOGRAM.
C     DOUBLE PRECISION TAPERP
C        THE PERCENT OF THE SERIES TO BE TAPERED.
C     DOUBLE PRECISION Y(150)
C         THE ARRAY CONTAINING THE TIME SERIES FROM JENKINS AND WATTS.
C     DOUBLE PRECISION YFFT(400)
C        THE VECTOR OF THE OBSERVED TIME SERIES TO BE ANALYZED USING
C        THE FFT.
C     DOUBLE PRECISION Z(275)
C        THE ARRAY OF THE WOLF SUNSPOT NUMBERS.
C     DOUBLE PRECISION ZFFT(600)
C        THE VECTOR OF THE TAPERED WOLF SUNSPOT NUMBERS TO BE
C        ANALYZED USING THE FFT.
C     DOUBLE PRECISION ZT(275)
C        THE ARRAY OF THE TAPERED SUNSPOT NUMBERS.
C
      DATA   Y(  1),  Y(  2),  Y(  3),  Y(  4),  Y(  5),  Y(  6)
     +    / -.88D0,  -.12D0,  -.89D0, -1.38D0,  -.07D0,  1.03D0/
      DATA   Y(  7),  Y(  8),  Y(  9),  Y( 10),  Y( 11),  Y( 12)
     +    / 2.14D0,   .35D0, -1.10D0, -1.78D0, -2.76D0, -1.77D0/
      DATA   Y( 13),  Y( 14),  Y( 15),  Y( 16),  Y( 17),  Y( 18)
     +    /  .98D0,  1.00D0,  -.70D0, -1.01D0, -1.30D0,  -.85D0/
      DATA   Y( 19),  Y( 20),  Y( 21),  Y( 22),  Y( 23),  Y( 24)
     +    / -.46D0,  1.63D0,   .06D0,  -.17D0, -1.01D0, -1.04D0/
      DATA   Y( 25),  Y( 26),  Y( 27),  Y( 28),  Y( 29),  Y( 30)
     +    / -.66D0, -1.12D0,  -.51D0,  -.71D0,  -.20D0,  -.13D0/
      DATA   Y( 31),  Y( 32),  Y( 33),  Y( 34),  Y( 35),  Y( 36)
     +    /  .14D0,  1.59D0,  -.76D0, -1.08D0, -1.77D0, -1.20D0/
      DATA   Y( 37),  Y( 38),  Y( 39),  Y( 40),  Y( 41),  Y( 42)
     +    /  .45D0,  -.07D0,  -.63D0,  -.35D0,  -.87D0,  -.62D0/
      DATA   Y( 43),  Y( 44),  Y( 45),  Y( 46),  Y( 47),  Y( 48)
     +    /  .28D0,  1.90D0,  2.14D0,  1.05D0,   .31D0,  1.07D0/
      DATA   Y( 49),  Y( 50)
     +    / 2.67D0,  2.44D0/
C
      DATA   Z(  1),  Z(  2),  Z(  3),  Z(  4),  Z(  5),  Z(  6)
     +    /  5.0D0,  11.0D0,  16.0D0,  23.0D0,  36.0D0,  58.0D0/
      DATA   Z(  7),  Z(  8),  Z(  9),  Z( 10),  Z( 11),  Z( 12)
     +    / 29.0D0,  20.0D0,  10.0D0,   8.0D0,   3.0D0,   0.0D0/
      DATA   Z( 13),  Z( 14),  Z( 15),  Z( 16),  Z( 17),  Z( 18)
     +    /  0.0D0,   2.0D0,  11.0D0,  27.0D0,  47.0D0,  63.0D0/
      DATA   Z( 19),  Z( 20),  Z( 21),  Z( 22),  Z( 23),  Z( 24)
     +    / 60.0D0,  39.0D0,  28.0D0,  26.0D0,  22.0D0,  11.0D0/
      DATA   Z( 25),  Z( 26),  Z( 27),  Z( 28),  Z( 29),  Z( 30)
     +    / 21.0D0,  40.0D0,  78.0D0, 122.0D0, 103.0D0,  73.0D0/
      DATA   Z( 31),  Z( 32),  Z( 33),  Z( 34),  Z( 35),  Z( 36)
     +    / 47.0D0,  35.0D0,  11.0D0,   5.0D0,  16.0D0,  34.0D0/
      DATA   Z( 37),  Z( 38),  Z( 39),  Z( 40),  Z( 41),  Z( 42)
     +    / 70.0D0,  81.0D0, 111.0D0, 101.0D0,  73.0D0,  40.0D0/
      DATA   Z( 43),  Z( 44),  Z( 45),  Z( 46),  Z( 47),  Z( 48)
     +    / 20.0D0,  16.0D0,   5.0D0,  11.0D0,  22.0D0,  40.0D0/
      DATA   Z( 49),  Z( 50),  Z( 51),  Z( 52),  Z( 53),  Z( 54)
     +    / 60.0D0,  80.9D0,  83.4D0,  47.7D0,  47.8D0,  30.7D0/
      DATA   Z( 55),  Z( 56),  Z( 57),  Z( 58),  Z( 59),  Z( 60)
     +    / 12.2D0,   9.6D0,  10.2D0,  32.4D0,  47.6D0,  54.0D0/
      DATA   Z( 61),  Z( 62),  Z( 63),  Z( 64),  Z( 65),  Z( 66)
     +    / 62.9D0,  85.9D0,  61.2D0,  45.1D0,  36.4D0,  20.9D0/
      DATA   Z( 67),  Z( 68),  Z( 69),  Z( 70),  Z( 71),  Z( 72)
     +    / 11.4D0,  37.8D0,  69.8D0, 106.1D0, 100.8D0,  81.6D0/
      DATA   Z( 73),  Z( 74),  Z( 75),  Z( 76),  Z( 77),  Z( 78)
     +    / 66.5D0,  34.8D0,  30.6D0,   7.0D0,  19.8D0,  92.5D0/
      DATA   Z( 79),  Z( 80),  Z( 81),  Z( 82),  Z( 83),  Z( 84)
     +    /154.4D0, 125.9D0,  84.8D0,  68.1D0,  38.5D0,  22.8D0/
      DATA   Z( 85),  Z( 86),  Z( 87),  Z( 88),  Z( 89),  Z( 90)
     +    / 10.2D0,  24.1D0,  82.9D0, 132.0D0, 130.9D0, 118.1D0/
      DATA   Z( 91),  Z( 92),  Z( 93),  Z( 94),  Z( 95),  Z( 96)
     +    / 89.9D0,  66.6D0,  60.0D0,  46.9D0,  41.0D0,  21.3D0/
      DATA   Z( 97),  Z( 98),  Z( 99),  Z(100),  Z(101),  Z(102)
     +    / 16.0D0,   6.4D0,   4.1D0,   6.8D0,  14.5D0,  34.0D0/
      DATA   Z(103),  Z(104),  Z(105),  Z(106),  Z(107),  Z(108)
     +    / 45.0D0,  43.1D0,  47.5D0,  42.2D0,  28.1D0,  10.1D0/
      DATA   Z(109),  Z(110),  Z(111),  Z(112),  Z(113),  Z(114)
     +    /  8.1D0,   2.5D0,   0.0D0,   1.4D0,   5.0D0,  12.2D0/
      DATA   Z(115),  Z(116),  Z(117),  Z(118),  Z(119),  Z(120)
     +    / 13.9D0,  35.4D0,  45.8D0,  41.1D0,  30.1D0,  23.9D0/
      DATA   Z(121),  Z(122),  Z(123),  Z(124),  Z(125),  Z(126)
     +    / 15.6D0,   6.6D0,   4.0D0,   1.8D0,   8.5D0,  16.6D0/
      DATA   Z(127),  Z(128),  Z(129),  Z(130),  Z(131),  Z(132)
     +    / 36.3D0,  49.6D0,  64.2D0,  67.0D0,  70.9D0,  47.8D0/
      DATA   Z(133),  Z(134),  Z(135),  Z(136),  Z(137),  Z(138)
     +    / 27.5D0,   8.5D0,  13.2D0,  56.9D0, 121.5D0, 138.3D0/
      DATA   Z(139),  Z(140),  Z(141),  Z(142),  Z(143),  Z(144)
     +    /103.2D0,  85.7D0,  64.6D0,  36.7D0,  24.2D0,  10.7D0/
      DATA   Z(145),  Z(146),  Z(147),  Z(148),  Z(149),  Z(150)
     +    / 15.0D0,  40.1D0,  61.5D0,  98.5D0, 124.7D0,  96.3D0/
      DATA   Z(151),  Z(152),  Z(153),  Z(154),  Z(155),  Z(156)
     +    / 66.6D0,  64.5D0,  54.1D0,  39.0D0,  20.6D0,   6.7D0/
      DATA   Z(157),  Z(158),  Z(159),  Z(160),  Z(161),  Z(162)
     +    /  4.3D0,  22.7D0,  54.8D0,  93.8D0,  95.8D0,  77.2D0/
      DATA   Z(163),  Z(164),  Z(165),  Z(166),  Z(167),  Z(168)
     +    / 59.1D0,  44.0D0,  47.0D0,  30.5D0,  16.3D0,   7.3D0/
      DATA   Z(169),  Z(170),  Z(171),  Z(172),  Z(173),  Z(174)
     +    / 37.6D0,  74.0D0, 139.0D0, 111.2D0, 101.6D0,  66.2D0/
      DATA   Z(175),  Z(176),  Z(177),  Z(178),  Z(179),  Z(180)
     +    / 44.7D0,  17.0D0,  11.3D0,  12.4D0,   3.4D0,   6.0D0/
      DATA   Z(181),  Z(182),  Z(183),  Z(184),  Z(185),  Z(186)
     +    / 32.3D0,  54.3D0,  59.7D0,  63.7D0,  63.5D0,  52.2D0/
      DATA   Z(187),  Z(188),  Z(189),  Z(190),  Z(191),  Z(192)
     +    / 25.4D0,  13.1D0,   6.8D0,   6.3D0,   7.1D0,  35.6D0/
      DATA   Z(193),  Z(194),  Z(195),  Z(196),  Z(197),  Z(198)
     +    / 73.0D0,  85.1D0,  78.0D0,  64.0D0,  41.8D0,  26.2D0/
      DATA   Z(199),  Z(200),  Z(201),  Z(202),  Z(203),  Z(204)
     +    / 26.7D0,  12.1D0,   9.5D0,   2.7D0,   5.0D0,  24.4D0/
      DATA   Z(205),  Z(206),  Z(207),  Z(208),  Z(209),  Z(210)
     +    / 42.0D0,  63.5D0,  53.8D0,  62.0D0,  48.5D0,  43.9D0/
      DATA   Z(211),  Z(212),  Z(213),  Z(214),  Z(215),  Z(216)
     +    / 18.6D0,   5.7D0,   3.6D0,   1.4D0,   9.6D0,  47.4D0/
      DATA   Z(217),  Z(218),  Z(219),  Z(220),  Z(221),  Z(222)
     +    / 57.1D0, 103.9D0,  80.6D0,  63.6D0,  37.6D0,  26.1D0/
      DATA   Z(223),  Z(224),  Z(225),  Z(226),  Z(227),  Z(228)
     +    / 14.2D0,   5.8D0,  16.7D0,  44.3D0,  63.9D0,  69.0D0/
      DATA   Z(229),  Z(230),  Z(231),  Z(232),  Z(233),  Z(234)
     +    / 77.8D0,  64.9D0,  35.7D0,  21.2D0,  11.1D0,   5.7D0/
      DATA   Z(235),  Z(236),  Z(237),  Z(238),  Z(239),  Z(240)
     +    /  8.7D0,  36.1D0,  79.7D0, 114.4D0, 109.6D0,  88.8D0/
      DATA   Z(241),  Z(242),  Z(243),  Z(244),  Z(245),  Z(246)
     +    / 67.8D0,  47.5D0,  30.6D0,  16.3D0,   9.6D0,  33.2D0/
      DATA   Z(247),  Z(248),  Z(249),  Z(250),  Z(251),  Z(252)
     +    / 92.6D0, 151.6D0, 136.3D0, 134.7D0,  83.9D0,  69.4D0/
      DATA   Z(253),  Z(254),  Z(255),  Z(256),  Z(257),  Z(258)
     +    / 31.5D0,  13.9D0,   4.4D0,  38.0D0, 141.7D0, 190.2D0/
      DATA   Z(259),  Z(260),  Z(261)
     +    /184.8D0, 159.0D0, 112.3D0/
C
      ITEST = 1
C
C     MAKE CALLS WITH VALID DATA
C
      NY = 50
      NZ = 261
      NFFT = 514
      NPRT = 2
      LZFFT = 600
      LPER = 514
      LPERI = 514
      TAPERP = 0.10D0
      LFREQ = 300
      IEXTND = 0
      LAB = 600
      NK = 3
      K(1) = 8
      K(2) = 8
      K(3) = 8
C
      CALL IPRINT(IPRT)
C
C     TEST OF CENTER
C
    5 WRITE (IPRT, 1018)
      CALL CENTER (Z, NZ, ZT)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM CENTER
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (ZT(I), I = 1, NZ)
C
C     TEST OF TAPER
C
      WRITE (IPRT, 1015)
      CALL TAPER (Z, NZ, TAPERP, ZT)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM TAPER
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (ZT(I), I = 1, NZ)
C
C     TEST OF PGM
C
      WRITE (IPRT, 1013)
      CALL DCOPY (NZ, ZT, 1, ZFFT, 1)
      CALL PGM (ZFFT, NZ, LZFFT, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF FFTLEN
C
      WRITE (IPRT, 1026)
      CALL FFTLEN(NFFT-2, 2, NTEMP)
      WRITE(IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM FFTLEN
C
      IF (IERR.EQ.0) WRITE (IPRT, 1027) NTEMP
C
C     TEST OF PGMS
C
      NTEMP = NFFT-1
      WRITE (IPRT, 1025)
      CALL DCOPY (NZ, ZT, 1, ZFFT, 1)
      CALL PGMS (ZFFT, NZ, NTEMP, LZFFT, IEXTND, NF, PER, LPER, FREQ,
     +   LFREQ, -2)
      WRITE (IPRT, 1027) NTEMP
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM PGMS
C
      IF (IERR.EQ.0) THEN
        WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
        WRITE (IPRT, 1004) (PER(I), I = 1, NF)
      END IF
C
C     TEST OF MDFLT
C
      WRITE (IPRT, 1016)
      CALL MDFLT (PER, NF, NK, K, PERF, LDSTAK)
      WRITE (IPRT, 1002) IERR
      IF (IERR.EQ.0) THEN
C
C       PRINT RETURNED VARIABLES FROM MDFLT
C
        WRITE (IPRT, 1004) (PERF(I), I = 1, NF)
C
C       DISPLAY SMOOTHED PERIODOGRAM ON A LOG PLOT
C
        WRITE (IPRT, 1028)
        CALL PPL (PERF, FREQ, NF, 1)
      END IF
C
C     TEST OF IPGMP
C
      WRITE (IPRT, 1029)
      CALL IPGMP (PER, FREQ, NF, NZ, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF IPGMPS
C
      WRITE (IPRT, 1030)
      CALL IPGMPS (PER, FREQ, NF, NZ, LDSTAK, PERI, NPRT)
      WRITE (IPRT, 1002) IERR
      IF (IERR.EQ.0) THEN
C
C     PRINT RETURNED VARIABLES FROM IPGMPS
C
         WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
         WRITE (IPRT, 1004) (PERI(I), I = 1, NF)
      END IF
C
C     TEST OF IPGM
C
      WRITE (IPRT, 1017)
      CALL DCOPY (NZ, ZT, 1, ZFFT, 1)
      CALL IPGM (ZFFT, NZ, LZFFT, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF IPGMS
C
      WRITE (IPRT, 1014)
      CALL DCOPY (NZ, ZT, 1, ZFFT, 1)
      CALL IPGMS (ZFFT, NZ, LZFFT, LDSTAK, NF, PERI, LPERI, FREQ, LFREQ,
     +   NPRT)
      WRITE (IPRT, 1002) IERR
      IF (IERR.EQ.0) THEN
C
C     PRINT RETURNED VARIABLES FROM IPGMS
C
         WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
         WRITE (IPRT, 1004) (PERI(I), I = 1, NF)
      END IF
C
C     TEST OF FFTR (CENTERED DATA - O PERCENT TAPER)
C
      TAPERP = -1.0D0
      WRITE (IPRT, 1031)
      IF (NY.GE.1) CALL TAPER (Y, NY, TAPERP, YFFT)
      CALL FFTR (YFFT, NY, NFFT, IEXTND, NF, AB, LAB)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM FFTR
C
      IF (IERR.EQ.0) WRITE (IPRT, 1004) (AB(I), I = 1, NF)
C
      GO TO (10, 20, 30, 40) ITEST
C
C     CHECK MINIMUM PROBLEM SIZE
C
   10 ITEST = ITEST + 1
      NZ = 17
      NY = 17
      GO TO 5
C
C     CHECK VARIOUS OPTIONS
C
   20 ITEST = ITEST + 1
C
C     TEST OF MDFLT (ELEMENTS OF K NOT EVEN)
C
      K(1) = 7
      WRITE (IPRT, 1016)
      CALL MDFLT (PER, NF, NK, K, PERF, LDSTAK)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM MDFLT
C
      WRITE (IPRT, 1004) (PERF(I), I = 1, NF)
C
C     TEST OF PGMS (UNCENTERED DATA)
C
      IEXTND = 1
      NPRT = 1
      WRITE (IPRT, 1025)
      CALL DCOPY (NZ, Z, 1, ZFFT, 1)
      CALL PGMS (ZFFT, NZ, NFFT, LZFFT, IEXTND, NF, PER, LPER, FREQ,
     +   LFREQ, NPRT)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM PGMS
C
      WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
      WRITE (IPRT, 1004) (PER(I), I = 1, NF)
C
      NPRT = 2
      WRITE (IPRT, 1025)
      CALL DCOPY (NZ, Z, 1, ZFFT, 1)
      CALL PGMS (ZFFT, NZ, NFFT, LZFFT, IEXTND, NF, PER, LPER, FREQ,
     +   LFREQ, NPRT)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM PGMS
C
      WRITE (IPRT, 1004) (FREQ(I), I = 1, NF)
      WRITE (IPRT, 1004) (PER(I), I = 1, NF)
C
C     TEST OF FFTR (CENTERED DATA - 100 PERCENT TAPER)
C
      TAPERP = 1.1D0
      WRITE (IPRT, 1031)
      CALL TAPER (Y, NY, TAPERP, YFFT)
      CALL FFTR (YFFT, NY, NFFT, IEXTND, NF, AB, LAB)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM FFTR
C
      WRITE (IPRT, 1004) (AB(I), I = 1, NF)
C
C     TEST OF FFTR (CENTERED DATA - O PERCENT TAPER)
C
      TAPERP = -1.0D0
      WRITE (IPRT, 1031)
      CALL TAPER (Y, NY, TAPERP, YFFT)
      CALL FFTR (YFFT, NY, NFFT-1, IEXTND, NF, AB, NFFT-2)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VARIABLES FROM FFTR
C
      WRITE (IPRT, 1004) (AB(I), I = 1, NF)
C
C     PERFORM ERROR CHECKING
C
      NY = -1
      NZ = -1
      NFFT = 0
      NPRT = 2
      LZFFT = 0
      LPER = 0
      LPERI = 0
      TAPERP = 0.10D0
      LFREQ = 0
      IEXTND = 0
      LAB = 0
      NK = 0
      K(1) = 0
      K(2) = 0
      K(3) = 0
      GO TO 5
C
C     PERFORM MORE ERROR CHECKING
C
   30 ITEST = ITEST + 1
      NY = 50
      NZ = 261
      NPRT = 2
      LZFFT = 0
      LPER = 0
      LPERI = 0
      TAPERP = 0.10D0
      LFREQ = 0
      IEXTND = 0
      LAB = 0
      NK = 3
      K(1) = 0
      K(2) = 0
      K(3) = 0
      GO TO 5
C
   40 RETURN
C
C     FORMAT STATEMENTS
C
 1002 FORMAT (8H IERR IS, I5)
 1004 FORMAT (3(1X, E16.8))
 1013 FORMAT ('1', 11HTEST OF PGM)
 1014 FORMAT ('1', 13HTEST OF IPGMS)
 1015 FORMAT ('1', 13HTEST OF TAPER)
 1016 FORMAT ('1', 13HTEST OF MDFLT)
 1017 FORMAT ('1', 12HTEST OF IPGM)
 1018 FORMAT ('1', 14HTEST OF CENTER)
 1025 FORMAT ('1', 12HTEST OF PGMS)
 1026 FORMAT ('1', 14HTEST OF FFTLEN)
 1027 FORMAT (/8H NFFT IS, I6)
 1028 FORMAT ('1', 45HDISPLAY OF PERIODOGRAM SMOOTHED WITH MODIFIED,
     +   14H DANIEL FILTER)
 1029 FORMAT ('1', 13HTEST OF IPGMP)
 1030 FORMAT ('1', 14HTEST OF IPGMPS)
 1031 FORMAT ('1', 12HTEST OF FFTR)
      END
