*XUAS
      SUBROUTINE XUAS(LDSTAK)
C
C     LATEST REVISION  -  03/15/90  (JRD)
C
C     ROUTINE TO TEST THE AUTOREGRESSIVE SPECTRUM ANALYSIS ROUTINES
C
C     SERIES Y IS THE FIRST 50 VALUES OF THE SERIES LISTED ON PAGE
C     318 OF JENKINS AND WATTS.  THE SPECTRUM OF THIS SERIES IS SHOWN
C     FOR VARIOUS BANDWIDTH ON PAGE 270 OF JENKINS AND WATTS.
C
C     WRITTEN BY - JANET R. DONALDSON
C                  STATISTICAL ENGINEERING DIVISION
C                  NATIONAL BUREAU OF STANDARDS, BOULDER, COLORADO
C
C     CREATION DATE  -  JUNE 10, 1982
C
C
C  VARIABLE DECLARATIONS
C
C  SCALAR ARGUMENTS
      INTEGER
     +   LDSTAK
C
C  SCALARS IN COMMON
      INTEGER
     +   IERR
C
C  ARRAYS IN COMMON
      DOUBLE PRECISION DSTAK(12)
C
C  LOCAL SCALARS
      DOUBLE PRECISION
     +   FMAX,FMIN,YMISS
      INTEGER
     +   I,IAR,IPRT,LACOV,LAG,LAGMAX,LDS,LYFFT,NF,NPRT,NY
C
C  LOCAL ARRAYS
      DOUBLE PRECISION
     +   ACOV(101),FREQ(300),PHI(101),SPCA(101),SPCF(101),Y(150),
     +   YFFT(400)
C
C  EXTERNAL SUBROUTINES
      EXTERNAL ACFS,IPRINT,DCOPY,SETRV,UAS,UASF,UASFS,UASS,UASV,UASVS
C
C  INTRINSIC FUNCTIONS
      INTRINSIC ABS
C
C  COMMON BLOCKS
      COMMON /CSTAK/DSTAK
      COMMON /ERRCHK/IERR
C
C     VARIABLE DEFINITIONS (ALPHABETICALLY)
C
C     DOUBLE PRECISION ACOV(101)
C        THE AUTOCOVARIANCE VECTOR.
C     DOUBLE PRECISION DSTAK(12)
C        THE DOUBLE PRECISION VERSION OF THE /CSTAK/ WORK AREA.
C     DOUBLE PRECISION FMAX, FMIN
C        THE MAXIMUM AND MINIMUM FREQUENCIES AT WHICH THE
C        SPECTRUM IS TO BE COMPUTED.
C     DOUBLE PRECISION FREQ(300)
C        THE VECTOR OF FREQUENCIES AT WHICH THE SPECTRUM IS COMPUTED.
C     INTEGER I
C        AN INDEX VARIABLE
C     INTEGER IAR
C        THE ORDER OF THE AUTOREGRESSIVE MODEL TO BE USED.
C     INTEGER IERR
C        THE INTEGER VALUE RETURNED BY THIS ROUTINE DESIGNATING
C        WHETHER ANY ERRORS WERE DETECTED IN THE PARAMETER LIST
C        IF IERR .EQ. 0, NO ERRORS WERE DETECTED
C        IF IERR .EQ. 1, ERRORS HAVE BEEN DETECTED
C     INTEGER IPRT
C        THE LOGICAL UNIT USED FOR PRINTED OUTPUT.
C     INTEGER LACOV
C        THE LENGTH OF THE VECTOR ACOV.
C     INTEGER LAG, LAGMAX
C        THE INDEXING VARIABLE INDICATING THE LAG VALUE OF THE
C        AUTOCOVARIANCE BEING COMPUTED AND THE MAXIMUM LAG TO BE USED,
C        RESPECTIVELY.
C     INTEGER LDS
C        THE LENGTH OF THE VECTOR DSTAK IN COMMON CSTAK.
C     INTEGER LYFFT
C        THE LENGTH OF THE VECTOR YFFT.
C     INTEGER NF
C        THE NUMBER OF FREQUENCIES AT WHICH THE SPECTRUM IS
C        TO BE COMPUTED.
C     INTEGER NPRT
C        A CODE USED TO SPECIFY THE TYPE OF PLOT, WHERE IF
C        NPRT < 0 THE PLOT IS DECIBLES/LINEAR
C        NPRT = 0 THE PLOT IS SUPPRESSED
C        NPRT > 0 THE PLOT IS LOG/LINEAR
C     INTEGER NY
C        THE NUMBER OF OBSERVATIONS IN THE SERIES Y.
C     DOUBLE PRECISION PHI(101)
C        THE VECTOR OF THE ORDER IAR AUTOREGRESSIVE MODEL COEFFICIENTS.
C     DOUBLE PRECISION SPCA(101)
C        THE ARRAYS IN WHICH THE AUTOREGRESSIVE SPECTRUM IS STORED
C        FOR EACH LAG WINDOW.
C     DOUBLE PRECISION SPCF(101)
C        THE ARRAYS IN WHICH THE FOURIER SPECTRUM IS STORED
C        FOR EACH LAG WINDOW.
C     DOUBLE PRECISION Y(150)
C         THE ARRAY CONTAINING THE TIME SERIES FROM JENKINS AND WATTS.
C     DOUBLE PRECISION YFFT(400)
C        THE VECTOR OF THE OBSERVED TIME SERIES TO BE ANALYZED USING
C        THE FFT.
C     DOUBLE PRECISION YMISS
C        THE USER SUPPLIED CODE WHICH IS USED TO DETERMINE WHETHER OR
C        NOT AN OBSERVATION IN THE SERIES IS MISSING.  IF Y(I) = YMISS,
C        THE VALUE IS ASSUMED MISSING, OTHERWISE IT IS NOT.
C
C
      DATA   Y(  1), Y(  2), Y(  3), Y(  4), Y(  5), Y(  6)
     +    /-0.88D0, -0.12D0, -0.89D0, -1.38D0, -0.07D0,  1.03D0/
      DATA   Y(  7), Y(  8), Y(  9), Y( 10), Y( 11), Y( 12)
     +    / 2.14D0,  0.35D0, -1.10D0, -1.78D0, -2.76D0, -1.77D0/
      DATA   Y( 13), Y( 14), Y( 15), Y( 16), Y( 17), Y( 18)
     +    / 0.98D0,  1.00D0, -0.70D0, -1.01D0, -1.30D0, -0.85D0/
      DATA   Y( 19), Y( 20), Y( 21), Y( 22), Y( 23), Y( 24)
     +    /-0.46D0,  1.63D0,  0.06D0, -0.17D0, -1.01D0, -1.04D0/
      DATA   Y( 25), Y( 26), Y( 27), Y( 28), Y( 29), Y( 30)
     +    /-0.66D0, -1.12D0, -0.51D0, -0.71D0, -0.20D0, -0.13D0/
      DATA   Y( 31), Y( 32), Y( 33), Y( 34), Y( 35), Y( 36)
     +    / 0.14D0,  1.59D0, -0.76D0, -1.08D0, -1.77D0, -1.20D0/
      DATA   Y( 37), Y( 38), Y( 39), Y( 40), Y( 41), Y( 42)
     +    / 0.45D0, -0.07D0, -0.63D0, -0.35D0, -0.87D0, -0.62D0/
      DATA   Y( 43), Y( 44), Y( 45), Y( 46), Y( 47), Y( 48)
     +    / 0.28D0,  1.90D0,  2.14D0,  1.05D0,  0.31D0,  1.07D0/
      DATA   Y( 49), Y( 50)
     +    / 2.67D0,  2.44D0/
C
C
      CALL IPRINT(IPRT)
C
C     CHECK ERROR HANDLING
C
C        TEST 1  -  MISCELANEOUS ERROR CHECKING
C
      WRITE (IPRT, 2000)
      YMISS = 1.16D0
      LAGMAX = -1
      NY = -10
      LACOV = 101
      LAG = -2
      IAR = -2
      LYFFT = -11
      NF = -5
      FMIN = 0.5D0
      FMAX = 0.0D0
      NPRT = -1
      LDS = 0
      WRITE(IPRT, 1001)
      CALL UAS(Y, NY)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT,SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1019)
      CALL UASF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1020)
      CALL UASFS(YFFT, NY, LYFFT, LDS, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1007)
      CALL UASV(ACOV, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1008)
      CALL UASVS(ACOV, LAGMAX, Y, NY, IAR, PHI, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C        TEST 2  -  MISCELANEOUS ERROR CHECKING (CONTINUED)
C
      WRITE (IPRT, 2010)
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 50
      LAG = 101
      IAR = 101
      CALL SETRV(PHI, IAR, 2.0D0)
      CALL SETRV(ACOV, LAGMAX+1, 2.0D0)
      ACOV(1) = 1.0D0
      LYFFT = -11
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 5
      LDS = 0
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1019)
      CALL UASF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1020)
      CALL UASFS(YFFT, NY, LYFFT, LDS, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1007)
      CALL UASV(ACOV, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1008)
      CALL UASVS(ACOV, LAGMAX, Y, NY, IAR, PHI, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C        TEST 3  -  LDS TOO SMALL
C
      WRITE (IPRT, 2030)
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      LAG = 16
      IAR = 2
      PHI(1) = 1.0D0
      PHI(2) = -0.5D0
      CALL ACFS (Y, NY, LAGMAX, LACOV, ACOV, IAR, PHI, 0, 700)
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 3
      LDS = 0
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1019)
      CALL UASF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1020)
      CALL UASFS(YFFT, NY, LYFFT, LDS, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1008)
      CALL UASVS(ACOV, LAGMAX, Y, NY, IAR, PHI, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     CHECK RESULTS FROM VALID CALL
C
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      LAG = 16
      IAR = 2
      PHI(1) = 1.0D0
      PHI(2) = -0.5D0
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 2
      LDS = 700
C
C     TEST OF UAS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1001)
      CALL UAS(Y, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UASS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
C     TEST OF UASF
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1019)
      CALL DCOPY(NY, Y, 1, YFFT, 1)
      CALL UASF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UASFS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1020)
      CALL DCOPY(NY, Y, 1, YFFT, 1)
      CALL UASFS(YFFT, NY, LYFFT, LDS, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASFS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
C     TEST OF UASV
C
      WRITE(IPRT, 2020)
      WRITE (IPRT, 1007)
      CALL UASV(ACOV, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UASVS
C
      WRITE(IPRT, 2020)
      WRITE (IPRT, 1008)
      CALL UASVS(ACOV, LAGMAX, Y, NY, IAR, PHI, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASVS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
C     MINIMUM PROBLEM SIZE
C
      YMISS = 1.16D0
      NY = 17
      LAGMAX = 1
      LYFFT = 400
      LAG = 1
      IAR = -1
      PHI(1) = 1.0D0
      PHI(2) = -0.5D0
      NF = 1
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 2
      LDS = LDSTAK
C
C     TEST OF UAS
C
      WRITE (IPRT, 2060)
      WRITE(IPRT, 1001)
      CALL UAS(Y, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UASS
C
      WRITE(IPRT, 2060)
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
C     CHECK HANDLING OF FMIN AND FMAX, AND LAG.EQ.0 AND IAR.EQ.0
C
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      LAG = 0
      IAR = 0
      PHI(1) = 1.0D0
      PHI(2) = -0.5D0
      NF = 51
      FMIN = 0.45D0
      FMAX = 0.5D0
      NPRT = 2
C
C     TEST OF UASS
C
      WRITE(IPRT, 2070)
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
C     WHITE NOISE SPECTRUM
C
      YMISS = 1.16D0
      CALL SETRV(YFFT, NY, 0.0D0)
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      LAG = 16
      IAR = 2
      PHI(1) = 1.0D0
      PHI(2) = -0.5D0
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 2
C
C     TEST OF UASS
C
      WRITE(IPRT, 2080)
      WRITE(IPRT, 1003)
      CALL UASS(YFFT, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
C     SUPPRESS OUTPUT AND
C     CHECK HANDLING OF LAG .LT.0 AND IAR .LT. 0
C
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      LAG = 0
      IAR = 0
      PHI(1) = 1.0D0
      PHI(2) = -0.5D0
      NF = 51
      FMIN = 0.45D0
      FMAX = 0.5D0
      NPRT = 0
C
C     TEST OF UASS
C
      WRITE(IPRT, 2090)
      WRITE(IPRT, 1003)
      CALL UASS(Y, NY, IAR, PHI, LAGMAX, LAG, NF,
     +   FMIN, FMAX, NPRT, SPCA, SPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UASS
C
      WRITE (IPRT, 1004) (FREQ(I), SPCA(I), SPCF(I), I=1,NF)
      WRITE (IPRT, 1005) IAR, LAG
      WRITE (IPRT, 1006) (PHI(I), I=1,ABS(IAR))
C
      RETURN
C
C     FORMAT STATEMENTS
C
 1001 FORMAT (12H TEST OF UAS)
 1002 FORMAT (/8H IERR IS, I5/)
 1003 FORMAT (13H TEST OF UASS)
 1004 FORMAT (3(1X, E16.8))
 1005 FORMAT (/7H IAR = , I5/7H LAG = , I5)
 1006 FORMAT (/7H PHI = , (1X, 5D21.8))
 1007 FORMAT (13H TEST OF UASV)
 1008 FORMAT (14H TEST OF UASVS)
 1019 FORMAT (13H TEST OF UASF)
 1020 FORMAT (14H TEST OF UASFS)
 2000 FORMAT (32H1CHECK ERROR HANDLING  -  TEST 1)
 2010 FORMAT (32H1CHECK ERROR HANDLING  -  TEST 2)
 2020 FORMAT (14H1VALID PROBLEM)
 2030 FORMAT (14H1LDS TOO SMALL)
 2060 FORMAT (21H1MINIMUM PROBLEM SIZE)
 2070 FORMAT (
     +   59H1CHECK HANDLING OF FMIN AND FMAX, LAG AND IAR EQUAL TO ZERO)
 2080 FORMAT (21H1WHITE NOISE SPECTRUM)
 2090 FORMAT (44H1SUPPRESS OUTPUT, LAG AND IAR LESS THAN ZERO)
      END
