*XUFS
      SUBROUTINE XUFS(LDSTAK)
C
C     LATEST REVISION  -  03/15/90  (JRD)
C
C     ROUTINE TO TEST THE FOURIER SPECTRUM ANALYSIS ROUTINES
C
C     SERIES Y IS THE FIRST 50 VALUES OF THE SERIES LISTED ON PAGE
C     318 OF JENKINS AND WATTS.  THE SPECTRUM OF THIS SERIES IS SHOWN
C     FOR VARIOUS BANDWIDTH ON PAGE 270 OF JENKINS AND WATTS.
C
C     SERIES Z IS THE WOLF SUNSPOT NUMBERS FROM 1700 TO 1960 AS
C     TABULATED BY WALDMEIER.  THE RAW AND SMOOTHED PERIODOGRAMS OF
C     TAPERED SERIES ARE SHOWN ON PAGES 95 AND 176, RESPECTIVELY, OF
C     BLOOMFIELD.
C
C     WRITTEN BY - JANET R. DONALDSON
C                  STATISTICAL ENGINEERING DIVISION
C                  NATIONAL BUREAU OF STANDARDS, BOULDER, COLORADO
C
C     CREATION DATE  -  DECEMBER 7, 1981
C
C
C  VARIABLE DECLARATIONS
C
C  SCALAR ARGUMENTS
      INTEGER
     +   LDSTAK
C
C  SCALARS IN COMMON
      INTEGER
     +   IERR
C
C  ARRAYS IN COMMON
      DOUBLE PRECISION DSTAK(12)
C
C  LOCAL SCALARS
      DOUBLE PRECISION
     +   AMISS,FMAX,FMIN,YMISS
      INTEGER
     +   I,IAR,IPRT,ISPCF,J,LACOV,LAGMAX,LDS,LYFFT,NF,NPRT,NW,NY
C
C  LOCAL ARRAYS
      DOUBLE PRECISION
     +   ACOV(101),FREQ(300),PHI(100),SPCF(101,4),Y(150),YFFT(400)
      INTEGER
     +   LAGS(4),NLPPA(101)
C
C  EXTERNAL SUBROUTINES
      EXTERNAL ACFMS,ACFS,IPRINT,NRAND,DCOPY,SETRV,UFS,UFSF,UFSFS,UFSM,
     +   UFSMS,UFSMV,UFSMVS,UFSS,UFSV,UFSVS
C
C  COMMON BLOCKS
      COMMON /CSTAK/DSTAK
      COMMON /ERRCHK/IERR
C
C     VARIABLE DEFINITIONS (ALPHABETICALLY)
C
C     DOUBLE PRECISION ACOV(101)
C        THE AUTOCOVARIANCE VECTOR.
C     DOUBLE PRECISION AMISS
C         THE MISSING VALUE CODE FOR THE RETURNED ACVF ESTIMATES.
C     DOUBLE PRECISION DSTAK(12)
C        THE DOUBLE PRECISION VERSION OF THE /CSTAK/ WORK AREA.
C     DOUBLE PRECISION FMAX, FMIN
C        THE MAXIMUM AND MINIMUM FREQUENCIES AT WHICH THE
C        SPECTRUM IS TO BE COMPUTED.
C     DOUBLE PRECISION FREQ(300)
C        THE VECTOR OF FREQUENCIES AT WHICH THE SPECTRUM IS COMPUTED.
C     INTEGER I
C        AN INDEX VARIABLE
C     INTEGER IAR
C        THE ORDER OF THE AUTOREGRESSIVE MODEL TO BE USED.
C     INTEGER IERR
C        THE INTEGER VALUE RETURNED BY THIS ROUTINE DESIGNATING
C        WHETHER ANY ERRORS WERE DETECTED IN THE PARAMETER LIST
C        IF IERR .EQ. 0, NO ERRORS WERE DETECTED
C        IF IERR .EQ. 1, ERRORS HAVE BEEN DETECTED
C     INTEGER IPRT
C        THE LOGICAL UNIT USED FOR PRINTED OUTPUT.
C     INTEGER ISPCF
C         THE ACTUAL DIMENSION FOR THE SPECTRUM ARRAYS.
C     INTEGER J
C        INDEX VARIABLE.
C     INTEGER LACOV
C        THE LENGTH OF THE VECTOR ACOV.
C     INTEGER LAGMAX
C        THE INDEXING VARIABLE INDICATING THE LAG VALUE OF THE
C        AUTOCOVARIANCE BEING COMPUTED AND THE MAXIMUM LAG TO BE USED,
C        RESPECTIVELY.
C     INTEGER LAGS(4)
C        THE ARRAY USED TO STORE THE LAG WINDOW TRUCCATION
C        POINTS USED FOR EACH SET OF SPECTRUM VALUES.
C     INTEGER LDS
C        THE LENGTH OF THE VECTOR DSTAK IN COMMON CSTAK.
C     INTEGER LYFFT
C        THE LENGTH OF THE VECTOR YFFT.
C     INTEGER NF
C        THE NUMBER OF FREQUENCIES AT WHICH THE SPECTRUM IS
C        TO BE COMPUTED.
C     INTEGER NLPPA(101)
C        THE NUMBERS OF LAGGED PRODUCT PAIRS USED FOR EACH ACVF.
C     INTEGER NPRT
C        A CODE USED TO SPECIFY THE TYPE OF PLOT, WHERE IF
C        NPRT = 0 THE PLOT IS SUPPRESSED, IF
C        NPRT = 2 THE PLOT IS DECIBELS/LINEAR, IF
C        NPRT = 2 THE PLOT IS LOG/LINEAR, IF
C        NPRT = 3 THE PLOT IS DECIBELS/LOG, AND IF
C        NPRT = 4 THE PLOT IS LOG/LOG.
C     INTEGER NW
C        THE NUMBER OF DIFFERENT LAG WINDOW TRUNCATION POINTS SPECIFIED,
C        AND THEREFORE, THE NUMBER OF PLOTS.
C     INTEGER NY
C        THE NUMBER OF OBSERVATIONS IN THE SERIES Y.
C     DOUBLE PRECISION PHI(100)
C        THE VECTOR OF THE ORDER IAR AUTOREGRESSIVE MODEL COEFFICIENTS.
C     DOUBLE PRECISION SPCF(101, 4)
C        THE ARRAYS IN WHICH THE FOURIER SPECTRUM IS STORED
C        FOR EACH LAG WINDOW.
C     DOUBLE PRECISION Y(150)
C         THE ARRAY CONTAINING THE TIME SERIES FROM JENKINS AND WATTS.
C     DOUBLE PRECISION YFFT(400)
C        THE VECTOR OF THE OBSERVED TIME SERIES TO BE ANALYZED USING
C        THE FFT.
C     DOUBLE PRECISION YMISS
C        THE USER SUPPLIED CODE WHICH IS USED TO DETERMINE WHETHER OR
C        NOT AN OBSERVATION IN THE SERIES IS MISSING.  IF Y(I) = YMISS,
C        THE VALUE IS ASSUMED MISSING, OTHERWISE IT IS NOT.
C
C
      DATA   Y(  1), Y(  2), Y(  3), Y(  4), Y(  5), Y(  6)
     +    /-0.88D0, -0.12D0, -0.89D0, -1.38D0, -0.07D0,  1.03D0/
      DATA   Y(  7), Y(  8), Y(  9), Y( 10), Y( 11), Y( 12)
     +    / 2.14D0,  0.35D0, -1.10D0, -1.78D0, -2.76D0, -1.77D0/
      DATA   Y( 13), Y( 14), Y( 15), Y( 16), Y( 17), Y( 18)
     +    / 0.98D0,  1.00D0, -0.70D0, -1.01D0, -1.30D0, -0.85D0/
      DATA   Y( 19), Y( 20), Y( 21), Y( 22), Y( 23), Y( 24)
     +    /-0.46D0,  1.63D0,  0.06D0, -0.17D0, -1.01D0, -1.04D0/
      DATA   Y( 25), Y( 26), Y( 27), Y( 28), Y( 29), Y( 30)
     +    /-0.66D0, -1.12D0, -0.51D0, -0.71D0, -0.20D0, -0.13D0/
      DATA   Y( 31), Y( 32), Y( 33), Y( 34), Y( 35), Y( 36)
     +    / 0.14D0,  1.59D0, -0.76D0, -1.08D0, -1.77D0, -1.20D0/
      DATA   Y( 37), Y( 38), Y( 39), Y( 40), Y( 41), Y( 42)
     +    / 0.45D0, -0.07D0, -0.63D0, -0.35D0, -0.87D0, -0.62D0/
      DATA   Y( 43), Y( 44), Y( 45), Y( 46), Y( 47), Y( 48)
     +    / 0.28D0,  1.90D0,  2.14D0,  1.05D0,  0.31D0,  1.07D0/
      DATA   Y( 49), Y( 50)
     +    / 2.67D0,  2.44D0/
C
      CALL IPRINT(IPRT)
C
C     CHECK ERROR HANDLING
C
C        TEST 1  -  MISCELANEOUS ERROR CHECKING
C
      WRITE (IPRT, 2000)
      YMISS = 1.16D0
      LAGMAX = -1
      NY = -10
      LACOV = 101
      LYFFT = -11
      NW = -1
      NF = -5
      FMIN = 0.5D0
      FMAX = 0.0D0
      NPRT = -1
      ISPCF = -20
      LDS = 0
      WRITE(IPRT, 1001)
      CALL UFS (Y, NY)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1003)
      CALL UFSS(Y, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1019)
      CALL UFSF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1020)
      CALL UFSFS(YFFT, NY, LYFFT, LDS, NW, LAGS, NF, FMIN, FMAX, NPRT,
     +   SPCF, ISPCF, FREQ)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1005)
      CALL UFSM (Y, YMISS, NY)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1006)
      CALL UFSMS(Y, YMISS, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1007)
      CALL UFSV(ACOV, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1008)
      CALL UFSVS (ACOV, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1021)
      CALL UFSMV(ACOV, NLPPA, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1022)
      CALL UFSMVS (ACOV, NLPPA, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C        TEST 2  -  MISCELANEOUS ERROR CHECKING (CONTINUED)
C
      WRITE (IPRT, 2010)
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 55
      LYFFT = -11
      NW = 2
      LAGS(1) = 0
      LAGS(2) = 50
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 3
      ISPCF = 20
      LDS = 0
      WRITE(IPRT, 1003)
      CALL UFSS(Y, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1019)
      CALL UFSF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1020)
      CALL UFSFS(YFFT, NY, LYFFT, LDS, NW, LAGS, NF, FMIN, FMAX, NPRT,
     +   SPCF, ISPCF, FREQ)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1006)
      CALL UFSMS(Y, YMISS, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1008)
      CALL UFSVS (ACOV, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1022)
      CALL UFSMVS (ACOV, NLPPA, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C        TEST 3  -  LDS TOO SMALL
C
      WRITE (IPRT, 2030)
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      NW = 2
      LAGS(1) = 0
      LAGS(2) = 50
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 3
      ISPCF = 101
      LDS = 0
      WRITE(IPRT, 1003)
      CALL UFSS(Y, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1019)
      CALL UFSF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1020)
      CALL UFSFS(YFFT, NY, LYFFT, LDS, NW, LAGS, NF, FMIN, FMAX, NPRT,
     +   SPCF, ISPCF, FREQ)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1006)
      CALL UFSMS(Y, YMISS, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1008)
      CALL UFSVS (ACOV, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1022)
      CALL UFSMVS (ACOV, NLPPA, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C        TEST 4  -  ALL DATA AND COVARIANCES MISSING
C
      WRITE (IPRT, 2040)
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      NW = 2
      LAGS(1) = 8
      LAGS(2) = 16
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 3
      ISPCF = 101
      LDS = 700
      CALL SETRV(YFFT, NY, YMISS)
      CALL SETRV(ACOV, LAGMAX, 0.0D0)
      DO 5 I = 1, LAGMAX
         NLPPA(I) = 0
    5 CONTINUE
      WRITE (IPRT, 1005)
      CALL UFSM(YFFT, YMISS, NY)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1006)
      CALL UFSMS(YFFT, YMISS, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1021)
      CALL UFSMV (ACOV, NLPPA, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
      WRITE (IPRT, 1022)
      CALL UFSMVS (ACOV, NLPPA, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C        TEST 5  -  EVERY OTHER VALUE MISSING
C
      WRITE (IPRT, 2050)
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      NW = 2
      LAGS(1) = 8
      LAGS(2) = 16
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 3
      ISPCF = 101
      LDS = 700
      CALL SETRV(YFFT, NY, YMISS)
      DO 10 I = 1, NY, 2
         YFFT(I) = Y(I)
   10 CONTINUE
      WRITE (IPRT, 1005)
      CALL UFSM(YFFT, YMISS, NY)
      WRITE (IPRT, 1002) IERR
      WRITE(IPRT, 1006)
      CALL UFSMS(YFFT, YMISS, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     CHECK RESULTS FROM VALID CALL
C
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      NW = 2
      LAGS(1) = 8
      LAGS(2) = 16
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 2
      ISPCF = 101
      LDS = LDSTAK
C
C     TEST OF UFS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1001)
      CALL UFS (Y, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UFSS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1003)
      CALL UFSS(Y, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     TEST OF UFSF
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1019)
      CALL DCOPY(NY, Y, 1, YFFT, 1)
      CALL UFSF (YFFT, NY, LYFFT, LDS)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UFSFS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1020)
      CALL DCOPY(NY, Y, 1, YFFT, 1)
      CALL UFSFS(YFFT, NY, LYFFT, LDS, NW, LAGS, NF, FMIN, FMAX, NPRT,
     +   SPCF, ISPCF, FREQ)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSFS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     TEST OF UFSM
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1005)
      CALL UFSM (Y, YMISS, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UFSMS
C
      WRITE(IPRT, 2020)
      WRITE(IPRT, 1006)
      CALL UFSMS(Y, YMISS, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSMS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     TEST OF UFSV
C
      WRITE(IPRT, 2020)
      CALL ACFS (Y, NY, LAGMAX, LACOV, ACOV, IAR, PHI, 0, LDS)
      WRITE (IPRT, 1007)
      CALL UFSV(ACOV, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UFSVS
C
      WRITE(IPRT, 2020)
      WRITE (IPRT, 1008)
      CALL UFSVS (ACOV, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSVS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     TEST OF UFSMV
C
      WRITE(IPRT, 2020)
      CALL ACFMS (Y, YMISS, NY, LAGMAX, LACOV, ACOV, AMISS, NLPPA,
     +   0, LDS)
      WRITE (IPRT, 1021)
      CALL UFSMV(ACOV, NLPPA, LAGMAX, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UFSMVS
C
      WRITE(IPRT, 2020)
      WRITE (IPRT, 1022)
      CALL UFSMVS (ACOV, NLPPA, LAGMAX, NY, NW, LAGS, NF,
     +   FMIN, FMAX, NPRT, SPCF, ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSMVS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     MINIMUM PROBLEM SIZE
C
      YMISS = 1.16D0
      NY = 17
      LAGMAX = 1
      LYFFT = 400
      NW = 2
      LAGS(1) = 1
      LAGS(2) = 16
      NF = 1
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 2
      ISPCF = 101
      LDS = 700
C
C     TEST OF UFS
C
      WRITE (IPRT, 2060)
      WRITE(IPRT, 1001)
      CALL UFS (Y, NY)
      WRITE (IPRT, 1002) IERR
C
C     TEST OF UFSS
C
      WRITE(IPRT, 2060)
      WRITE(IPRT, 1003)
      CALL UFSS(Y, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     CHECK HANDLING OF FMIN AND FMAX
C
      YMISS = 1.16D0
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      NW = 2
      LAGS(1) = 8
      LAGS(2) = 16
      NF = 51
      FMIN = 0.45D0
      FMAX = 0.5D0
      NPRT = 2
      ISPCF = 101
      LDS = 700
C
C     TEST OF UFSS
C
      WRITE(IPRT, 2070)
      WRITE(IPRT, 1003)
      CALL UFSS(Y, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
C     WHITE NOISE SPECTRUM
C
      YMISS = 1.16D0
      CALL NRAND(YFFT, NY, 12345)
      NY = 50
      LAGMAX = 49
      LYFFT = 400
      NW = 2
      LAGS(1) = 8
      LAGS(2) = 16
      NF = 51
      FMIN = 0.0D0
      FMAX = 0.5D0
      NPRT = 2
      ISPCF = 101
      LDS = 700
C
C     TEST OF UFSS
C
      WRITE(IPRT, 2080)
      WRITE(IPRT, 1003)
      CALL UFSS(YFFT, NY, NW, LAGS, NF, FMIN, FMAX, NPRT, SPCF,
     +   ISPCF, FREQ, LDS)
      WRITE (IPRT, 1002) IERR
C
C     PRINT RETURNED VALUES FROM UFSS
C
      WRITE (IPRT, 1004) (FREQ(I), (SPCF(I,J),J=1,NW), I=1,NF)
C
      RETURN
C
C     FORMAT STATEMENTS
C
 1001 FORMAT (12H TEST OF UFS)
 1002 FORMAT (/8H IERR IS, I5/)
 1003 FORMAT (13H TEST OF UFSS)
 1004 FORMAT (3(1X, E16.8))
 1005 FORMAT (13H TEST OF UFSM)
 1006 FORMAT (14H TEST OF UFSMS)
 1007 FORMAT (13H TEST OF UFSV)
 1008 FORMAT (14H TEST OF UFSVS)
 1019 FORMAT (13H TEST OF UFSF)
 1020 FORMAT (14H TEST OF UFSFS)
 1021 FORMAT (14H TEST OF UFSMV)
 1022 FORMAT (15H TEST OF UFSMVS)
 2000 FORMAT (32H1CHECK ERROR HANDLING  -  TEST 1)
 2010 FORMAT (32H1CHECK ERROR HANDLING  -  TEST 2)
 2020 FORMAT (14H1VALID PROBLEM)
 2030 FORMAT (14H1LDS TOO SMALL)
 2040 FORMAT (33H1ALL DATA AND COVARIANCES MISSING)
 2050 FORMAT (31H1EVERY OTHER DATA VALUE MISSING)
 2060 FORMAT (21H1MINIMUM PROBLEM SIZE)
 2070 FORMAT (32H1CHECK HANDLING OF FMIN AND FMAX)
 2080 FORMAT (21H1WHITE NOISE SPECTRUM)
      END
