*CORRMN
      SUBROUTINE CORRMN(YM, N, M, IYM, AVG, SD, T, RANK, SC, PC, SCINV,
     +   IWRK, WRK, SLSC, SLPC, SRCC, QUAD, CIUP, CILO, QF, NPRT,
     +   VCV, IVCV, LIWRK, LWRK)
C
C     LATEST REVISION  -  03/15/90  (JRD)
C
C     THIS IS THE MAIN ROUTINE FOR THE CORRELATION FAMILY, IT WAS
C     ADAPTED FROM THE OMNITAB ROUTINE CORREL. IT DOES A  CORRELATION
C     ANALYSIS OF A MULTIVARIATE RANDOM SAMPLE.
C     THE FOLLOWING TABLES ARE PRODUCED
C        SIMPLE CORRELATION COEFFICIENTS,
C        PARTIAL CORRELATION COEFFICIENTS,
C        AND THEIR SIGINIFICANCE LEVELS,
C        SPEARMAN RANK COEFFICIENTS,
C        QUADRATIC RELATIONSHIP,
C        95 AND 99 PERCENT CONFIDENCE INTERVALS.
C
C     THIS ROUTINE WAS ADAPTED FROM AN OMNITAB ROUTINE.
C
C     ADAPTED BY -
C        JANET R. DONALDSON AND LINDA L. MITCHELL
C        STATISTICAL ENGINEERING DIVISION
C        NATIONAL BUREAU OF STANDARDS, BOULDER, COLORADO
C
C     CREATION DATE  -  MAY 17, 1982
C
C
C  VARIABLE DECLARATIONS
C
C  SCALAR ARGUMENTS
      INTEGER
     +   IVCV,IYM,LIWRK,LWRK,M,N,NPRT
C
C  ARRAY ARGUMENTS
      REAL
     +   AVG(M),CILO(M,M),CIUP(M,M),PC(M,M),QF(M,M),QUAD(N,3),
     +   RANK(N,M),SC(M,M),SCINV(M,M),SD(M),SLPC(M,M),SLSC(M,M),
     +   SRCC(M,M),T(M),VCV(IVCV,M),WRK(LWRK),YM(IYM,M)
      INTEGER
     +   IWRK(LIWRK)
C
C  SCALARS IN COMMON
      INTEGER
     +   IERR
C
C  LOCAL SCALARS
      REAL
     +   B,F,FN3,FPLM,HL1,HL2,SQSUM,SUM,Z,ZZ
      INTEGER
     +   I,IER,IPRT,J,K,K1,K2,NSUM
C
C  LOCAL ARRAYS
      REAL
     +   C(3),D(3),RR(3,3),XX(3)
      INTEGER
     +   INERT(3)
C
C  EXTERNAL FUNCTIONS
      REAL
     +   CDFF,R1MACH
      EXTERNAL CDFF,R1MACH
C
C  EXTERNAL SUBROUTINES
      EXTERNAL AMEAN,CORRHD,DOTC,IPRINT,MATPRT,MGS,RANKO,SSIDI,SSIFA,
     +   VCVOUT
C
C  INTRINSIC FUNCTIONS
      INTRINSIC ABS,INT,LOG,MAX,MIN,REAL,SIGN,SQRT,TANH
C
C  COMMON BLOCKS
      COMMON /ERRCHK/IERR
C
C
C     VARIABLE DEFINITIONS (ALPHABETICALLY)
C
C     REAL AVG(M)
C                  CONTAINS THE COLUMN AVERAGES OF YM
C     REAL B
C                  = (N-1) * N * (N+1) / 6
C     REAL C(3)
C                  *
C     REAL CILO(M,M)
C                  LOWER CONFIDENCE INTERVAL FOR SC
C     REAL CIUP(M,M)
C                  UPPER CONFIDENCE INTERVAL FOR SC
C     REAL D(3)
C                  A DUMMY ARRAY.
C     REAL F
C                  SQUARE ROOT OF FN3
C     REAL FN3
C                  REAL REPRESENTATION OF (N-3).
C     REAL FPLM
C                  THE FLOATING POINT LARGEST MAGNITUDE
C     REAL HL1
C                  *
C     REAL HL2
C                  *
C     INTEGER I
C                  AN INDEX VARIABLE
C     INTEGER IER
C                  ERROR FLAG FOR SUBROUTINES CALLED FROM THIS ROUTINE
C     INTEGER IERR
C                  WHEN RETURNED BY THIS ROUTINE, DESGINATES WHETHER ANY
C                  ERRORS WERE DETECTED DURING COMPUTATIONS
C                     IF IERR .EQ. 0, NO ERRORS
C                             .EQ. 1, ERRORS WERE DETECTED
C     INTEGER INERT(3)
C                  THE INERTIA OF THE SIMPLE CORRELATION MATRIX.
C     INTEGER IPRT
C                  THE LOGICAL OUTPUT NUMBER
C     INTEGER IVCV
C                  THE ROW DIMENSION OF VCV SPECIFIED IN THE USERS PROGR
C     INTEGER IWRK(LIWRK)
C                  A WORK VECTOR FOR THE INVERSION ROUTINE
C     INTEGER IYM
C                  THE ROW DIMENSION OF YM SPECIFIED IN THE USERS PROGRA
C     INTEGER J
C                  AN INDEX VARIABLE
C     INTEGER K
C                  AN INDEX VARIABLE
C     INTEGER K1
C                  *
C     INTEGER K2
C                  *
C     INTEGER LIWRK
C                  THE LENGTH OF THE INTEGER WORK VECTOR.
C     INTEGER LWRK
C                  THE LENGTH OF THE REAL WORK VECTOR.
C     INTEGER M
C                  THE NUMBER OF VARIABLES (THE COLUMN DIMENSION OF YM)
C     INTEGER N
C                  THE NUMBER OF OBSERVATIONS
C     INTEGER NPRT
C                  THE VARIABLE CONTROLLING THE AUTOMATIC PRINTOUT
C                  NPRT =0, PRINTOUT IS SUPPRESSED
C                  OTHERWISE PRINTOUT IS PROVIDED
C     INTEGER NSUM
C                  THE NUMBER OF OBSERVATIONS IN THE DOT PRODUCT
C     REAL PC(M,M)
C                  PARTIAL CORRELATION COEFFICIENTS MATRIX
C     REAL QF(M,M)
C                  QUADRATIC FIX MATRIX
C     REAL QUAD(N,3)
C                  DOUBLE VERSION OF QF MATRIX
C     REAL RANK(N,M)
C                  THE MATRIX CONTAING THE RANKS OF YM
C     REAL RR(3,3)
C                  *
C     REAL SC(M,M)
C                  SIMPLE CORRELATION COEFFICIENTS MATRIX
C     REAL SCINV(M,M)
C                  THE INVERSE MATRIX OF SC
C     REAL SD(M)
C                  STANDARD DEVIATION OF THE COMLUMNS OF YM
C     REAL SLPC(M,M)
C                  SIGNIFICANCE LEVELS OF PC
C     REAL SLSC(M,M)
C                  SIGNIFICANCE LEVELS OF SC
C     REAL SQSUM
C                  THE SUM OF SQUARES OF THE ITH COLUMN OF YM
C     REAL SRCC(M,M)
C                  SPEARMAN RANK CORRELATION COEFFICIENTS
C     REAL SUM
C                  USED IN CALCULATING THE STATISTICS OF YM
C     REAL T(M)
C                  USED IN DETERMINING SRCC
C     REAL VCV(IVCV,M)
C                  THE VARIANCE COVARIANCE MATRIX.
C     REAL WRK(LWRK)
C                  WORK STORAGE
C     REAL XX(3)
C                  *
C     REAL YM(IYM,M)
C                  THE MATRIX WHOSE COLUMNS EACH CONTAIN ONE OF M SETS
C                  OF N OBSERVATIONS. EACH COLUMN REPRESENTS A DIFFERENT
C                  VARIABLE
C     REAL Z
C                  USED IN COMPUTING CONFIDENCE INTERVALS
C     REAL ZZ
C                  USED IN DETERMINING CORRELATION COEFFICIENTS
C
      IERR = 0
C
      FPLM = R1MACH(2)
      CALL IPRINT(IPRT)
C
      DO 10 J=1,M
         CALL AMEAN(YM(1,J), N, AVG(J))
   10 CONTINUE
C
C     COMPUTE VARIANCE-COVARIANCE MATRIX
C
      DO 30 J=1,M
         DO 20 I=J,M
            CALL DOTC(YM(1,J), AVG(J), N, YM(1,I), AVG(I), N, SUM, NSUM)
            VCV(J,I) = SUM/(NSUM-1)
            VCV(I,J) = VCV(J,I)
   20    CONTINUE
   30 CONTINUE
C
      IF (NPRT.EQ.0) RETURN
C
C     PRINT VARIANCE-COVARIANCE MATRIX AND SIMPLE CORRELATION
C     COEFFICIENTS
C
      CALL CORRHD(IPRT, M, N)
      CALL VCVOUT(M, VCV, IVCV, .FALSE.)
C
C     COMPUTE STANDARD DEVIATIONS
C
      DO 40 I=1,M
         IF (VCV(I,I).LE.0.0E0) GO TO 90
         SD(I) = SQRT(VCV(I,I))
   40 CONTINUE
C
C     COMPUTE SIMPLE CORRELATION COEFFICIENTS
C
      DO 60 J=1,M
         DO 50 I=J,M
            SC(I,J) = 1.0E0
            SCINV(J,I) = 1.0E0
            IF (I.EQ.J) GO TO 50
            SC(I,J) = VCV(I,J)/SD(I)/SD(J)
            SC(J,I) = SC(I,J)
            SCINV(J,I) = SC(I,J)
   50    CONTINUE
   60 CONTINUE
C
      IF ((M.LE.2) .OR. (N.LE.M)) GO TO 190
C
C     CALCULATE PARTIAL CORRELATION COEFFICIENTS.
C
      CALL SSIFA(SCINV, M, M, IWRK, IER)
      IF (IER.EQ.0) GO TO 100
   90 WRITE (IPRT,1000)
      IERR = 1
      RETURN
  100 CONTINUE
      CALL SSIDI(SCINV, M, M, IWRK, D, INERT, WRK, 1)
      DO 130 J=1,M
         DO 120 I=J,M
            PC(I,J) = 1.0E0
            IF (I.EQ.J) GO TO 120
            ZZ = SCINV(I,I)*SCINV(J,J)
            PC(I,J) = FPLM
            IF (ZZ.LE.0.0E0) GO TO 110
            PC(I,J) = -SCINV(J,I)/SQRT(ZZ)
            IF (ABS(PC(I,J)).GT.1.0E0) PC(I,J) = SIGN(1.0E0,PC(I,J))
  110       PC(J,I) = PC(I,J)
  120    CONTINUE
C
  130 CONTINUE
C
C     COMPUTE SIGNIFICANCE LEVELS OF PARTIAL CORRELATION COEFFICIENTS.
C     NOTE, LOWER TRIANGULAR MATRIX STORED IN SQUARE MATRIX.
C
      DO 180 I=1,M
         DO 170 J=1,I
            IF (PC(I,J).NE.0.0E0) GO TO 140
            SLPC(I,J) = 1.0E0
            GO TO 170
  140       IF (ABS(PC(I,J)).LT.1.0E0) GO TO 150
            SLPC(I,J) = 0.0E0
            GO TO 170
  150       F = PC(I,J)*PC(I,J)
            IF (1.0E0-F.NE.0.0E0) GO TO 160
            SLPC(I,J) = FPLM
            GO TO 170
  160       F = (N-M)*F/(1.0E0-F)
            SLPC(I,J) = 1.0E0 - CDFF(F,1.0E0,REAL(N-M))
  170    CONTINUE
  180 CONTINUE
C
C     COMPUTE SIGNIFICANCE LEVELS OF SIMPLE CORRELATION COEFFICIENTS
C     NOTE, ONLY LOWER TRIANGULAR STORED IN SQUARE MATRIX.
C
  190 DO 250 I=1,M
         DO 240 J=1,I
            IF (I.NE.J) GO TO 200
            SLSC(I,J) = 0.0E0
            GO TO 240
  200       IF (SC(I,J).NE.0.0E0) GO TO 210
            SLSC(I,J) = 1.0E0
            GO TO 240
  210       IF (ABS(SC(I,J)).LT.1.0E0) GO TO 220
            SLSC(I,J) = 0.0E0
            GO TO 240
  220       F = SC(I,J)*SC(I,J)
            IF (F.NE.1.0E0) GO TO 230
            SLSC(I,J) = FPLM
            GO TO 240
  230       F = (N-2)*F/(1.0E0-F)
            SLSC(I,J) = 1.0E0 - CDFF(F,1.0E0,REAL(N-2))
  240    CONTINUE
  250 CONTINUE
C
C     PRINT SIGNIFICANCE LEVELS OF SIMPLE CORRELATION COEFFICIENTS,
C     PARTIAL CORRELATION COEFFICIENTS AND SIGNIFICANCE LEVELS
C
      WRITE (IPRT,1020)
      CALL MATPRT(SLSC, SLSC, M, IPRT, 0, 1, M)
      IF ((M.GT.2) .AND. (N.GT.M)) GO TO 260
      WRITE (IPRT,1010)
      GO TO 270
  260 I = M - 2
      WRITE (IPRT,1030) I
      CALL MATPRT(PC, PC, M, IPRT, 0, 1, M)
      WRITE (IPRT,1040)
      CALL MATPRT(SLPC, SLPC, M, IPRT, 0, 1, M)
  270 CONTINUE
C
C     DETERMINE THE RANKS OF THE OBSERVATIONS.
C
      DO 280 I=1,M
         CALL RANKO(N, YM(1,I), IWRK, RANK(1,I), T(I))
         T(I) = T(I) / 12.0E0
  280 CONTINUE
C
C     COMPUTE SPEARMAN RANK CORRELATION COEFFICIENTS.
C     NOTE, LOWER TRIANGULAR MATRIX, STORED IN SQUARE MATRIX.
C
      B = (N-1)*N*(N+1)/6
      DO 330 I=1,M
         DO 320 J=1,I
            SRCC(I,J) = 1.0E0
            IF (I.EQ.J) GO TO 320
            K1 = 2.0E0*T(I) + 0.4E0
            K2 = 2.0E0*T(J) + 0.4E0
            SRCC(I,J) = FPLM
            IF ((INT(B)-K1.LE.0) .OR. (INT(B)-K2.LE.0)) GO TO 320
            SUM = 0.0E0
            DO 310 K=1,N
               ZZ = RANK(K,I) - RANK(K,J)
               SUM = SUM + ZZ*ZZ
  310       CONTINUE
            ZZ = (B - 2.0E0*T(I))*(B - 2.0E0*T(J))
            IF (ZZ.GT.0.0E0) SRCC(I,J) = (B-SUM-T(I)-T(J))/SQRT(ZZ)
  320    CONTINUE
  330 CONTINUE
C
C     PRINT SPEARMAN RANK CORRELATIONS COEFFICIENTS
C
      WRITE (IPRT,1050)
      CALL MATPRT(SRCC, SRCC, M, IPRT, 0, 1, M)
C
      IF (N.GT.3) GO TO 340
      WRITE (IPRT,1060)
      RETURN
C
C     COMPUTE THE SIGNIFICANCE LEVELS OF THE QUADRATIC FIT OVER THE
C     LINEAR FIT.
C
C     THESE CALCULATIONS MAY PRODUCE VARIABLE RESULTS IN VARYING
C     MACHINE/COMPILATION ENVIRONMENTS, IN CASES IN WHICH THE
C     YM MATRIX IS NEAR SINGULAR (ESSENTIALLY SINGULAR BUT THE
C     SINGULARITY IS UNDETECTED BY THE CODE).  THE OBSERVED SYMPTOMS
C     ARE ALTERNATION BETWEEN QF VALUES OF 0.0E0 (FIRST F = LINE
C     PRODUCES ZERO) AND 1.0E0 (FIRST F = LINE PRODUCES APPROX.
C     ZERO, AND NUMERATOR IN SECOND F = LINE IS NONZERO).
C
  340 FN3 = N-3
      DO 410 J=1,M
         DO 400 I=1,M
            IF (I.NE.J) GO TO 350
            QF(I,J) = 1.0E0
            GO TO 400
  350       SQSUM = 0.0E0
            DO 360 K=1,N
              QUAD(K,1) = 1.0E0
               QUAD(K,2) = YM(K,J)
               QUAD(K,3) = YM(K,J)*YM(K,J)
               SQSUM = SQSUM + YM(K,I)*YM(K,I)
               WRK(K) = YM(K,I)
  360       CONTINUE
            CALL MGS(QUAD, WRK, N, 3, XX, C, D, RR, 3, N, IER)
            IF (IER.EQ.0) GO TO 370
            WRITE (IPRT,1090)
            GO TO 420
  370       DO 380 K=1,3
               C(K) = C(K)*SQRT(D(K))
  380       CONTINUE
            F = (SQSUM-C(1)*C(1)-C(2)*C(2)-C(3)*C(3))
            QF(I,J) = 0.0E0
            IF (F.EQ.0.0E0) GO TO 400
            F = (C(3)*C(3)*FN3)/F
            QF(I,J) = 1.0E0
            IF (F.GT.0.0E0) QF(I,J) = 1.0E0 - CDFF(F,1.0E0,FN3)
  400    CONTINUE
  410 CONTINUE
C
C     PRINT THE QUADRATIC FIT MATRIX
C
      J = 2
      K = 1
      I = N - 3
      WRITE (IPRT,1070) I, QF(J,K), J, K
      CALL MATPRT(QF, QF, M, IPRT, 1, 1, M)
C
C     COMPUTE CONFIDENCE LIMITS FOR SIMPLE CORRELATION COEFFICIENTS
C
  420 F = SQRT(FN3)
      HL1 = 2.5758293E0/F
      HL2 = 1.9599640E0/F
      DO 520 J=1,M
         DO 510 I=1,M
            IF (I.NE.J) GO TO 430
            CIUP(I,J) = 99.0E0
            CILO(I,J) = 95.0E0
            GO TO 510
  430       IF (I.LT.J) GO TO 470
C
C           COMPUTE 95 PERCENT INTERVALS.
C
            IF (SC(I,J).GE.1.0E0) GO TO 440
            IF (SC(I,J).GT.-1.0E0) GO TO 450
            Z = -1.0E0
            GO TO 460
  440       Z = 1.0E0
            GO TO 460
  450       Z = 0.5E0*LOG((1.0E0+SC(I,J))/(1.0E0-SC(I,J)))
  460       CIUP(I,J) = MIN(TANH(Z+HL2),1.0E0)
            CILO(I,J) = MAX(TANH(Z-HL2),-1.0E0)
            GO TO 510
C
C           COMPUTE 99 PERCENT INTERVALS.
C
  470       IF (SC(J,I).GE.1.0E0) GO TO 480
            IF (SC(J,I).GT.-1.0E0) GO TO 490
            Z = -1.0E0
            GO TO 500
  480       Z = 1.0E0
            GO TO 500
  490       Z = 0.5E0*LOG((1.0E0+SC(J,I))/(1.0E0-SC(J,I)))
  500       CIUP(I,J) = MIN(TANH(Z+HL1),1.0E0)
            CILO(I,J) = MAX(TANH(Z-HL1),-1.0E0)
  510    CONTINUE
  520 CONTINUE
C
C     PRINT CONFIDENCE LIMITS
C
      WRITE (IPRT,1080)
      CALL MATPRT(CIUP, CILO, M, IPRT, 1, 2, M)
C
      RETURN
C
C     FORMAT STATEMENTS
C
 1000 FORMAT (/ 46H COMPUTATION STOPPED DUE TO SINGULAR OR ILL-CO,
     +   28HNDITIONED COVARIANCE MATRIX.)
 1010 FORMAT (//42H THE PARTIAL CORRELATION COEFFICIENTS (AND, 6H SIGNI,
     +   50HFICANCE LEVELS) ARE NOT PRINTED OR DEFINED BECAUSE/6H EITHE,
     +   52HR THE NUMBER OF VECTORS BEING COMPARED IS TWO OR THE,
     +   59H NUMBER OF MEASUREMENTS IS LESS THAN OR EQUAL TO THE NUMBER/
     +   27H OF VECTORS BEING COMPARED.)
 1020 FORMAT (// 44H SIGNIFICANCE LEVELS OF SIMPLE CORRELATION C,
     +   32HOEFFICIENTS (ASSUMING NORMALITY))
 1030 FORMAT (// 38H PARTIAL CORRELATION COEFFICIENTS WITH, I3,
     +   26H REMAINING VARIABLES FIXED)
 1040 FORMAT (// 44H SIGNIFICANCE LEVELS OF PARTIAL CORRELATION ,
     +   33HCOEFFICIENTS (ASSUMING NORMALITY))
 1050 FORMAT (// 44H SPEARMAN RANK CORRELATION COEFFICIENTS (ADJ,
     +   15HUSTED FOR TIES))
 1060 FORMAT (// 44H NONLINEARITY TEST AND APPROXIMATION OF CONF,
     +   39HIDENCE INTERVALS NOT DEFINED FOR N = 3.)
 1070 FORMAT (// 45H SIGNIFICANCE LEVEL OF QUADRATIC FIT OVER LIN,
     +   35HEAR FIT BASED ON F RATIO WITH 1 AND, I5, 15H DEGREES OF FRE,
     +   4HEDOM/14H (FOR EXAMPLE,, F7.4, 19H IS THE SIGNIFICANC,
     +   41HE LEVEL OF THE QUADRATIC TERM WHEN COLUMN, I3, 9H IS FITTE,
     +   11HD TO COLUMN, I3, ')')
 1080 FORMAT (// 44H CONFIDENCE INTERVALS FOR SIMPLE CORRELATION,
     +   43H COEFFICIENTS (USING FISHER TRANSFORMATION)/' 95 PER C',
     +   59HENT LIMITS BELOW DIAGONAL, 99 PER CENT LIMITS ABOVE DIAGONA,
     +   'L')
 1090 FORMAT (/ 46H SIGNIFICANCE LEVELS OF QUADRATIC FIT OVER LIN,
     +   30HEAR FIT HAVE NOT BEEN COMPUTED/' DUE TO SINGULARITY IN',
     +   32H DESIGN MATRIX. CHECK YOUR DATA.)
      END
