*XXCH12
      SUBROUTINE XXCH12(LDSTAK)
C
C     LATEST REVISION  -  03/15/90  (JRD)
C
C     THIS SUBPROGRAM PROVIDES A SIMPLE TEST OF
C     THE TIME SERIES CORRELATION AND SPECTRUM ANALYSIS
C     FAMILY OF ROUTINES.
C
C     DATA FOR ACF IS TAKEN FROM P. 362 OF JENKINS AND WATTS [1968]
C     DATA FOR CCF IS TAKEN FROM P. 361 OF JENKINS AND WATTS [1968]
C     DATA FOR UFS IS TAKEN FROM P. 318 OF JENKINS AND WATTS [1968]
C     DATA FOR UAS IS TAKEN FROM P. 318 OF JENKINS AND WATTS [1968]
C     DATA FOR TAPER, PGMS, MDFLT AND PPL IS
C           THE WOLF SUNSPOT NUMBERS FOR THE YEARS 1700 TO 1960 AS
C           TABULATED BY WALDMEIER [1961].
C     DATA FOR BFS IS TAKEN FROM PP. 387-388 OF JENKINS AND WATTS [1968]
C
C     WRITTEN BY - JANET R. DONALDSON
C                  STATISTICAL ENGINEERING DIVISION
C                  NATIONAL BUREAU OF STANDARDS, BOULDER, COLORADO
C
C     CREATION DATE  -  AUGUST 3, 1987
C
C
C  VARIABLE DECLARATIONS
C
C  SCALAR ARGUMENTS
      INTEGER
     +   LDSTAK
C
C  SCALARS IN COMMON
      INTEGER
     +   IERR
C
C  ARRAYS IN COMMON
      DOUBLE PRECISION DSTAK(12)
C
C  LOCAL SCALARS
      REAL
     +   TAPERP
      INTEGER
     +   IEXTND,ILOG,IPRT,LFREQ,LPER,LYFFT,NF,NFFT,NK,NPRT,NY1,NY2,
     +   NY3,NY4,NY5,NY6
C
C  LOCAL ARRAYS
      REAL
     +   FREQ(300),PER(300),PERF(300),Y1(100),Y2A(100),Y2B(100),
     +   Y3(50),Y4(50),Y5(300),Y6A(100),Y6B(100),YFFT(600)
      INTEGER
     +   KMD(10)
C
C  EXTERNAL SUBROUTINES
      EXTERNAL ACF,BFS,CCF,IPRINT,MDFLT,PGMS,PPL,TAPER,UAS,UFS
C
C  COMMON BLOCKS
      COMMON /CSTAK/DSTAK
      COMMON /ERRCHK/IERR
C
C  EQUIVALENCES
      EQUIVALENCE (Y3(1),Y4(1))
      EQUIVALENCE (Y2A(1),Y6A(1))
      EQUIVALENCE (Y2B(1),Y6B(1))
C
C     VARIABLE DEFINITIONS (ALPHABETICALLY)
C
C     DOUBLE PRECISION DSTAK(12)
C        THE DOUBLE PRECISION VERSION OF THE /CSTAK/ WORK AREA.
C     REAL FREQ(300)
C        THE FREQUENCIES AT WHICH THE PERIODOGRAM IS COMPUTED.
C     INTEGER IERR
C        A COMMON VARIABLE USED AS A FLAG TO INDICATE WHETHER
C        OR NOT THERE ARE ANY ERRORS, IF =0 THEN NO ERRORS.
C     INTEGER IEXTND
C        THE INDICATOR VARIABLE USED TO DESIGNATE WHETHER ZERO OR THE
C        SERIES MEAN IS TO BE USED TO EXTEND THE SERIES.
C     INTEGER ILOG
C        THE INDICATOR VARIABLE USED TO DESIGNATE WHETHER THE PLOT IS
C        TO HAVE LOGARITHMIC AXIS OR NOT.
C     INTEGER IPRT
C        LOGICAL OUTPUT UNIT.
C     INTEGER KMD(10)
C        THE VECTOR OF MODIFIED DANIEL FILTER LENGTHS.
C     INTEGER LDSTAK
C        THE LENGTH OF DSTAK IN COMMON /CSTAK/.
C     INTEGER LFREQ
C        THE LENGTH OF VECTOR FREQ.
C     INTEGER LPER
C        THE LENGTH OF VECTOR PER.
C     INTEGER LYFFT
C        THE LENGTH OF VECTOR YFFT.
C     INTEGER NF
C        THE NUMBER OF FREQUENCIES.
C     INTEGER NFFT
C        THE EXTENDED SERIES LENGTH FOR THE FFT.
C     INTEGER NK
C        THE NUMBER OF DANIEL FILTERS TO APPLY.
C     INTEGER NPRT
C        THE PRINT CONTROL VARIABLE.
C     INTEGER NY1, NY2, NY3, NY4, NY5, NY6
C        THE NUMBER OF OBSERVATIONS.
C     REAL PER(300)
C        THE PERIODOGRAM.
C     REAL PERF(300)
C        THE FILTERED PERIODOGRAM.
C     REAL TAPERP
C        THE PERCENTAGE OF THE SERIES TO BE TAPERED.
C     REAL YFFT(600)
C        AN ARRAY FOR THE FFT COMPUTATIONS.
C     REAL Y1(100)
C        THE DATA FROM PAGE 362 OF JENKINS AND WATTS.
C     REAL Y2A(100), Y2B(100)
C        THE DATA FROM PAGE 361 OF JENKINS AND WATTS.
C     REAL Y3(50), Y4(50)
C        THE DATA FROM PAGE 318 OF JENKINS AND WATTS.
C     REAL Y5(300)
C        THE WOLF SUNSPOT DATA.
C     REAL Y6A(100), Y6B(100)
C        THE DATA FROM PAGE 387 AND 388 OF JENKINS AND WATTS.
C
C
      DATA   Y1(  1),  Y1(  2),  Y1(  3),  Y1(  4),  Y1(  5),  Y1(  6)
     +    / -2.07E0, -1.15E0,  0.69E0, -0.46E0, -1.49E0, -0.70E0/
      DATA   Y1(  7),  Y1(  8),  Y1(  9),  Y1( 10),  Y1( 11),  Y1( 12)
     +    / -1.07E0, -0.69E0, -0.68E0,  1.27E0, -1.05E0, -0.05E0/
      DATA   Y1( 13),  Y1( 14),  Y1( 15),  Y1( 16),  Y1( 17),  Y1( 18)
     +    / -0.84E0, -0.62E0, -0.49E0, -1.29E0, -0.49E0, -1.06E0/
      DATA   Y1( 19),  Y1( 20),  Y1( 21),  Y1( 22),  Y1( 23),  Y1( 24)
     +    / -0.38E0, -0.52E0, -0.13E0,  1.30E0, -1.51E0, -0.43E0/
      DATA   Y1( 25),  Y1( 26),  Y1( 27),  Y1( 28),  Y1( 29),  Y1( 30)
     +    / -1.33E0, -0.78E0,  0.31E0, -0.95E0, -0.90E0, -0.30E0/
      DATA   Y1( 31),  Y1( 32),  Y1( 33),  Y1( 34),  Y1( 35),  Y1( 36)
     +    / -1.02E0, -0.53E0,  0.15E0,  1.40E0,  1.22E0,  0.59E0/
      DATA   Y1( 37),  Y1( 38),  Y1( 39),  Y1( 40),  Y1( 41),  Y1( 42)
     +    /  0.70E0,  1.70E0,  2.78E0,  1.98E0,  1.39E0,  1.85E0/
      DATA   Y1( 43),  Y1( 44),  Y1( 45),  Y1( 46),  Y1( 47),  Y1( 48)
     +    /  2.60E0,  0.51E0,  2.77E0,  1.16E0,  1.07E0, -0.48E0/
      DATA   Y1( 49),  Y1( 50),  Y1( 51),  Y1( 52),  Y1( 53),  Y1( 54)
     +    / -0.52E0,  0.37E0,  0.00E0, -1.99E0, -1.75E0,  0.70E0/
      DATA   Y1( 55),  Y1( 56),  Y1( 57),  Y1( 58),  Y1( 59),  Y1( 60)
     +    /  0.73E0,  1.16E0,  0.06E0, -0.02E0,  1.10E0, -0.35E0/
      DATA   Y1( 61),  Y1( 62),  Y1( 63),  Y1( 64),  Y1( 65),  Y1( 66)
     +    / -1.67E0, -1.57E0,  1.16E0,  1.84E0,  3.35E0,  0.40E0/
      DATA   Y1( 67),  Y1( 68),  Y1( 69),  Y1( 70),  Y1( 71),  Y1( 72)
     +    /  0.45E0,  1.30E0,  0.93E0,  1.17E0, -1.74E0, -1.28E0/
      DATA   Y1( 73),  Y1( 74),  Y1( 75),  Y1( 76),  Y1( 77),  Y1( 78)
     +    / -0.07E0,  1.50E0,  0.53E0,  0.20E0, -0.42E0,  1.18E0/
      DATA   Y1( 79),  Y1( 80),  Y1( 81),  Y1( 82),  Y1( 83),  Y1( 84)
     +    /  0.82E0,  1.50E0,  2.92E0,  1.18E0,  1.23E0,  3.16E0/
      DATA   Y1( 85),  Y1( 86),  Y1( 87),  Y1( 88),  Y1( 89),  Y1( 90)
     +    /  0.79E0,  0.68E0,  1.14E0,  1.02E0,  1.02E0, -0.71E0/
      DATA   Y1( 91),  Y1( 92),  Y1( 93),  Y1( 94),  Y1( 95),  Y1( 96)
     +    / -0.17E0, -1.50E0, -0.26E0, -0.38E0,  0.93E0, -0.33E0/
      DATA   Y1( 97),  Y1( 98),  Y1( 99),  Y1(100)
     +    / -1.12E0, -2.95E0, -2.09E0, -1.11E0                    /
C
      DATA  Y2A(  1), Y2A(  2), Y2A(  3), Y2A(  4), Y2A(  5), Y2A(  6)
     +    /-0.88E0, -0.16E0, -1.87E0, -1.12E0,  1.38E0,  2.13E0/
      DATA  Y2A(  7), Y2A(  8), Y2A(  9), Y2A( 10), Y2A( 11), Y2A( 12)
     +    / 2.76E0,  0.56E0, -0.69E0, -1.79E0, -3.82E0, -2.38E0/
      DATA  Y2A( 13), Y2A( 14), Y2A( 15), Y2A( 16), Y2A( 17), Y2A( 18)
     +    / 1.00E0,  0.70E0, -0.15E0,  0.98E0,  0.11E0, -0.35E0/
      DATA  Y2A( 19), Y2A( 20), Y2A( 21), Y2A( 22), Y2A( 23), Y2A( 24)
     +    /-0.73E0,  0.89E0, -1.63E0, -0.44E0, -1.37E0, -1.71E0/
      DATA  Y2A( 25), Y2A( 26), Y2A( 27), Y2A( 28), Y2A( 29), Y2A( 30)
     +    /-1.22E0, -2.00E0, -0.22E0,  0.38E0,  1.31E0,  0.71E0/
      DATA  Y2A( 31), Y2A( 32), Y2A( 33), Y2A( 34), Y2A( 35), Y2A( 36)
     +    / 0.32E0,  0.48E0, -1.88E0, -0.94E0, -1.54E0, -0.13E0/
      DATA  Y2A( 37), Y2A( 38), Y2A( 39), Y2A( 40), Y2A( 41), Y2A( 42)
     +    / 1.02E0,  0.02E0, -0.77E0,  0.11E0, -0.60E0, -0.52E0/
      DATA  Y2A( 43), Y2A( 44), Y2A( 45), Y2A( 46), Y2A( 47), Y2A( 48)
     +    /-0.09E0,  1.23E0,  1.46E0,  0.61E0,  0.42E0,  2.16E0/
      DATA  Y2A( 49), Y2A( 50), Y2A( 51), Y2A( 52), Y2A( 53), Y2A( 54)
     +    / 3.18E0,  2.10E0,  0.37E0, -0.24E0,  0.57E0, -0.53E0/
      DATA  Y2A( 55), Y2A( 56), Y2A( 57), Y2A( 58), Y2A( 59), Y2A( 60)
     +    / 2.44E0,  1.02E0, -0.53E0, -2.49E0, -2.12E0, -1.04E0/
      DATA  Y2A( 61), Y2A( 62), Y2A( 63), Y2A( 64), Y2A( 65), Y2A( 66)
     +    /-0.12E0, -1.88E0, -1.50E0,  1.54E0,  3.33E0,  3.08E0/
      DATA  Y2A( 67), Y2A( 68), Y2A( 69), Y2A( 70), Y2A( 71), Y2A( 72)
     +    / 1.71E0,  0.79E0,  1.55E0,  0.89E0, -0.89E0, -1.18E0/
      DATA  Y2A( 73), Y2A( 74), Y2A( 75), Y2A( 76), Y2A( 77), Y2A( 78)
     +    / 0.89E0,  1.71E0,  3.05E0,  0.15E0, -1.04E0,  0.12E0/
      DATA  Y2A( 79), Y2A( 80), Y2A( 81), Y2A( 82), Y2A( 83), Y2A( 84)
     +    / 0.08E0,  0.11E0, -2.62E0, -1.28E0,  1.07E0,  3.20E0/
      DATA  Y2A( 85), Y2A( 86), Y2A( 87), Y2A( 88), Y2A( 89), Y2A( 90)
     +    / 1.92E0,  0.53E0, -1.08E0,  0.49E0, -0.58E0,  0.17E0/
      DATA  Y2A( 91), Y2A( 92), Y2A( 93), Y2A( 94), Y2A( 95), Y2A( 96)
     +    / 1.15E0, -0.97E0, -1.63E0,  1.14E0, -0.67E0, -0.88E0/
      DATA  Y2A( 97), Y2A( 98), Y2A( 99), Y2A(100)
     +    /-0.07E0,  0.24E0,  0.55E0, -2.16E0/
C
      DATA  Y2B(  1), Y2B(  2), Y2B(  3), Y2B(  4), Y2B(  5), Y2B(  6)
     +    / 0.79E0,  1.12E0, -1.10E0, -2.39E0, -1.75E0, -0.82E0/
      DATA  Y2B(  7), Y2B(  8), Y2B(  9), Y2B( 10), Y2B( 11), Y2B( 12)
     +    /-0.36E0,  1.27E0,  1.75E0,  2.44E0,  0.36E0, -2.10E0/
      DATA  Y2B( 13), Y2B( 14), Y2B( 15), Y2B( 16), Y2B( 17), Y2B( 18)
     +    /-1.93E0, -1.30E0, -1.75E0, -0.34E0,  0.74E0,  0.49E0/
      DATA  Y2B( 19), Y2B( 20), Y2B( 21), Y2B( 22), Y2B( 23), Y2B( 24)
     +    / 0.70E0,  0.71E0,  0.09E0,  0.59E0,  1.54E0,  0.14E0/
      DATA  Y2B( 25), Y2B( 26), Y2B( 27), Y2B( 28), Y2B( 29), Y2B( 30)
     +    / 0.55E0, -1.40E0, -2.55E0, -1.66E0, -0.43E0,  0.58E0/
      DATA  Y2B( 31), Y2B( 32), Y2B( 33), Y2B( 34), Y2B( 35), Y2B( 36)
     +    / 2.18E0, -0.24E0,  0.58E0, -0.18E0, -1.55E0, -0.64E0/
      DATA  Y2B( 37), Y2B( 38), Y2B( 39), Y2B( 40), Y2B( 41), Y2B( 42)
     +    /-1.09E0,  0.90E0, -0.66E0, -0.35E0,  0.48E0,  0.50E0/
      DATA  Y2B( 43), Y2B( 44), Y2B( 45), Y2B( 46), Y2B( 47), Y2B( 48)
     +    / 0.05E0, -0.68E0,  0.24E0,  0.58E0, -1.26E0, -0.25E0/
      DATA  Y2B( 49), Y2B( 50), Y2B( 51), Y2B( 52), Y2B( 53), Y2B( 54)
     +    / 0.25E0,  2.18E0,  2.96E0,  1.56E0, -0.36E0, -0.59E0/
      DATA  Y2B( 55), Y2B( 56), Y2B( 57), Y2B( 58), Y2B( 59), Y2B( 60)
     +    /-0.12E0,  3.03E0,  2.11E0,  0.78E0,  0.89E0, -1.45E0/
      DATA  Y2B( 61), Y2B( 62), Y2B( 63), Y2B( 64), Y2B( 65), Y2B( 66)
     +    /-0.36E0, -0.37E0, -1.39E0, -4.19E0, -0.73E0, -0.98E0/
      DATA  Y2B( 67), Y2B( 68), Y2B( 69), Y2B( 70), Y2B( 71), Y2B( 72)
     +    / 0.36E0,  0.06E0, -1.94E0, -0.08E0,  0.17E0,  1.00E0/
      DATA  Y2B( 73), Y2B( 74), Y2B( 75), Y2B( 76), Y2B( 77), Y2B( 78)
     +    /-0.05E0,  0.43E0,  0.15E0,  2.69E0,  0.57E0,  0.29E0/
      DATA  Y2B( 79), Y2B( 80), Y2B( 81), Y2B( 82), Y2B( 83), Y2B( 84)
     +    / 1.10E0,  0.48E0, -1.06E0, -2.28E0, -2.03E0, -0.75E0/
      DATA  Y2B( 85), Y2B( 86), Y2B( 87), Y2B( 88), Y2B( 89), Y2B( 90)
     +    / 1.00E0,  1.71E0,  0.58E0,  1.97E0,  0.99E0,  1.94E0/
      DATA  Y2B( 91), Y2B( 92), Y2B( 93), Y2B( 94), Y2B( 95), Y2B( 96)
     +    / 2.18E0,  3.14E0,  0.60E0,  0.51E0,  1.35E0,  0.56E0/
      DATA  Y2B( 97), Y2B( 98), Y2B( 99), Y2B(100)
     +    / 0.11E0,  0.00E0,  2.34E0,  1.88E0/
C
      DATA  Y3(  1),Y3(  2),Y3(  3),Y3(  4),Y3(  5),Y3(  6)
     +    /-0.88E0, -0.12E0, -0.89E0, -1.38E0, -0.07E0,  1.03E0/
      DATA  Y3(  7),Y3(  8),Y3(  9),Y3( 10),Y3( 11),Y3( 12)
     +    / 2.14E0,  0.35E0, -1.10E0, -1.78E0, -2.76E0, -1.77E0/
      DATA  Y3( 13),Y3( 14),Y3( 15),Y3( 16),Y3( 17),Y3( 18)
     +    / 0.98E0,  1.00E0, -0.70E0, -1.01E0, -1.30E0, -0.85E0/
      DATA  Y3( 19),Y3( 20),Y3( 21),Y3( 22),Y3( 23),Y3( 24)
     +    /-0.46E0,  1.63E0,  0.06E0, -0.17E0, -1.01E0, -1.04E0/
      DATA  Y3( 25),Y3( 26),Y3( 27),Y3( 28),Y3( 29),Y3( 30)
     +    /-0.66E0, -1.12E0, -0.51E0, -0.71E0, -0.20E0, -0.13E0/
      DATA  Y3( 31),Y3( 32),Y3( 33),Y3( 34),Y3( 35),Y3( 36)
     +    / 0.14E0,  1.59E0, -0.76E0, -1.08E0, -1.77E0, -1.20E0/
      DATA  Y3( 37),Y3( 38),Y3( 39),Y3( 40),Y3( 41),Y3( 42)
     +    / 0.45E0, -0.07E0, -0.63E0, -0.35E0, -0.87E0, -0.62E0/
      DATA  Y3( 43),Y3( 44),Y3( 45),Y3( 46),Y3( 47),Y3( 48)
     +    / 0.28E0,  1.90E0,  2.14E0,  1.05E0,  0.31E0,  1.07E0/
      DATA  Y3( 49),Y3( 50)
     +    / 2.67E0,  2.44E0/
C
      DATA  Y5(  1), Y5(  2), Y5(  3), Y5(  4), Y5(  5), Y5(  6)
     +    /     5.0E0, 11.0E0, 16.0E0, 23.0E0, 36.0E0, 58.0E0/
      DATA  Y5(  7), Y5(  8), Y5(  9), Y5( 10), Y5( 11), Y5( 12)
     +    /    29.0E0, 20.0E0, 10.0E0,  8.0E0,  3.0E0,  0.0E0/
      DATA  Y5( 13), Y5( 14), Y5( 15), Y5( 16), Y5( 17), Y5( 18)
     +    /     0.0E0, 2.0E0, 11.0E0, 27.0E0, 47.0E0, 63.0E0/
      DATA  Y5( 19), Y5( 20), Y5( 21), Y5( 22), Y5( 23), Y5( 24)
     +    /    60.0E0, 39.0E0, 28.0E0, 26.0E0, 22.0E0, 11.0E0/
      DATA  Y5( 25), Y5( 26), Y5( 27), Y5( 28), Y5( 29), Y5( 30)
     +    /    21.0E0, 40.0E0, 78.0E0,122.0E0,103.0E0, 73.0E0/
      DATA  Y5( 31), Y5( 32), Y5( 33), Y5( 34), Y5( 35), Y5( 36)
     +    /    47.0E0, 35.0E0, 11.0E0,  5.0E0, 16.0E0, 34.0E0/
      DATA  Y5( 37), Y5( 38), Y5( 39), Y5( 40), Y5( 41), Y5( 42)
     +    /    70.0E0, 81.0E0,111.0E0,101.0E0, 73.0E0, 40.0E0/
      DATA  Y5( 43), Y5( 44), Y5( 45), Y5( 46), Y5( 47), Y5( 48)
     +    /    20.0E0, 16.0E0,  5.0E0, 11.0E0, 22.0E0, 40.0E0/
      DATA  Y5( 49), Y5( 50), Y5( 51), Y5( 52), Y5( 53), Y5( 54)
     +    /    60.0E0, 80.9E0, 83.4E0, 47.7E0, 47.8E0, 30.7E0/
      DATA  Y5( 55), Y5( 56), Y5( 57), Y5( 58), Y5( 59), Y5( 60)
     +    /    12.2E0,  9.6E0, 10.2E0, 32.4E0, 47.6E0, 54.0E0/
      DATA  Y5( 61), Y5( 62), Y5( 63), Y5( 64), Y5( 65), Y5( 66)
     +    /    62.9E0, 85.9E0, 61.2E0, 45.1E0, 36.4E0, 20.9E0/
      DATA  Y5( 67), Y5( 68), Y5( 69), Y5( 70), Y5( 71), Y5( 72)
     +    /    11.4E0, 37.8E0, 69.8E0,106.1E0,100.8E0, 81.6E0/
      DATA  Y5( 73), Y5( 74), Y5( 75), Y5( 76), Y5( 77), Y5( 78)
     +    /    66.5E0, 34.8E0, 30.6E0,  7.0E0, 19.8E0, 92.5E0/
      DATA  Y5( 79), Y5( 80), Y5( 81), Y5( 82), Y5( 83), Y5( 84)
     +    /   154.4E0,125.9E0, 84.8E0, 68.1E0, 38.5E0, 22.8E0/
      DATA  Y5( 85), Y5( 86), Y5( 87), Y5( 88), Y5( 89), Y5( 90)
     +    /    10.2E0, 24.1E0, 82.9E0,132.0E0,130.9E0,118.1E0/
      DATA  Y5( 91), Y5( 92), Y5( 93), Y5( 94), Y5( 95), Y5( 96)
     +    /    89.9E0, 66.6E0, 60.0E0, 46.9E0, 41.0E0, 21.3E0/
      DATA  Y5( 97), Y5( 98), Y5( 99), Y5(100), Y5(101), Y5(102)
     +    /    16.0E0,  6.4E0,  4.1E0,  6.8E0, 14.5E0, 34.0E0/
      DATA  Y5(103), Y5(104), Y5(105), Y5(106), Y5(107), Y5(108)
     +    /    45.0E0, 43.1E0, 47.5E0, 42.2E0, 28.1E0, 10.1E0/
      DATA  Y5(109), Y5(110), Y5(111), Y5(112), Y5(113), Y5(114)
     +    /     8.1E0,  2.5E0,  0.0E0,  1.4E0,  5.0E0, 12.2E0/
      DATA  Y5(115), Y5(116), Y5(117), Y5(118), Y5(119), Y5(120)
     +    /    13.9E0, 35.4E0, 45.8E0, 41.1E0, 30.1E0, 23.9E0/
      DATA  Y5(121), Y5(122), Y5(123), Y5(124), Y5(125), Y5(126)
     +    /    15.6E0,  6.6E0,  4.0E0,  1.8E0,  8.5E0, 16.6E0/
      DATA  Y5(127), Y5(128), Y5(129), Y5(130), Y5(131), Y5(132)
     +    /    36.3E0, 49.6E0, 64.2E0, 67.0E0, 70.9E0, 47.8E0/
      DATA  Y5(133), Y5(134), Y5(135), Y5(136), Y5(137), Y5(138)
     +    /    27.5E0,  8.5E0, 13.2E0, 56.9E0,121.5E0,138.3E0/
      DATA  Y5(139), Y5(140), Y5(141), Y5(142), Y5(143), Y5(144)
     +    /   103.2E0, 85.7E0, 64.6E0, 36.7E0, 24.2E0, 10.7E0/
      DATA  Y5(145), Y5(146), Y5(147), Y5(148), Y5(149), Y5(150)
     +    /    15.0E0, 40.1E0, 61.5E0, 98.5E0,124.7E0, 96.3E0/
      DATA  Y5(151), Y5(152), Y5(153), Y5(154), Y5(155), Y5(156)
     +    /    66.6E0, 64.5E0, 54.1E0, 39.0E0, 20.6E0,  6.7E0/
      DATA  Y5(157), Y5(158), Y5(159), Y5(160), Y5(161), Y5(162)
     +    /     4.3E0, 22.7E0, 54.8E0, 93.8E0, 95.8E0, 77.2E0/
      DATA  Y5(163), Y5(164), Y5(165), Y5(166), Y5(167), Y5(168)
     +    /    59.1E0, 44.0E0, 47.0E0, 30.5E0, 16.3E0,  7.3E0/
      DATA  Y5(169), Y5(170), Y5(171), Y5(172), Y5(173), Y5(174)
     +    /    37.6E0, 74.0E0,139.0E0,111.2E0,101.6E0, 66.2E0/
      DATA  Y5(175), Y5(176), Y5(177), Y5(178), Y5(179), Y5(180)
     +    /    44.7E0, 17.0E0, 11.3E0, 12.4E0,  3.4E0,  6.0E0/
      DATA  Y5(181), Y5(182), Y5(183), Y5(184), Y5(185), Y5(186)
     +    /    32.3E0, 54.3E0, 59.7E0, 63.7E0, 63.5E0, 52.2E0/
      DATA  Y5(187), Y5(188), Y5(189), Y5(190), Y5(191), Y5(192)
     +    /    25.4E0, 13.1E0,  6.8E0,  6.3E0,  7.1E0, 35.6E0/
      DATA  Y5(193), Y5(194), Y5(195), Y5(196), Y5(197), Y5(198)
     +    /    73.0E0, 85.1E0, 78.0E0, 64.0E0, 41.8E0, 26.2E0/
      DATA  Y5(199), Y5(200), Y5(201), Y5(202), Y5(203), Y5(204)
     +    /    26.7E0, 12.1E0,  9.5E0,  2.7E0,  5.0E0, 24.4E0/
      DATA  Y5(205), Y5(206), Y5(207), Y5(208), Y5(209), Y5(210)
     +    /    42.0E0, 63.5E0, 53.8E0, 62.0E0, 48.5E0, 43.9E0/
      DATA  Y5(211), Y5(212), Y5(213), Y5(214), Y5(215), Y5(216)
     +    /    18.6E0,  5.7E0,  3.6E0,  1.4E0,  9.6E0, 47.4E0/
      DATA  Y5(217), Y5(218), Y5(219), Y5(220), Y5(221), Y5(222)
     +    /    57.1E0,103.9E0, 80.6E0, 63.6E0, 37.6E0, 26.1E0/
      DATA  Y5(223), Y5(224), Y5(225), Y5(226), Y5(227), Y5(228)
     +    /    14.2E0,  5.8E0, 16.7E0, 44.3E0, 63.9E0, 69.0E0/
      DATA  Y5(229), Y5(230), Y5(231), Y5(232), Y5(233), Y5(234)
     +    /    77.8E0, 64.9E0, 35.7E0, 21.2E0, 11.1E0,  5.7E0/
      DATA  Y5(235), Y5(236), Y5(237), Y5(238), Y5(239), Y5(240)
     +    /     8.7E0, 36.1E0, 79.7E0,114.4E0,109.6E0, 88.8E0/
      DATA  Y5(241), Y5(242), Y5(243), Y5(244), Y5(245), Y5(246)
     +    /    67.8E0, 47.5E0, 30.6E0, 16.3E0,  9.6E0, 33.2E0/
      DATA  Y5(247), Y5(248), Y5(249), Y5(250), Y5(251), Y5(252)
     +    /    92.6E0,151.6E0,136.3E0,134.7E0, 83.9E0, 69.4E0/
      DATA  Y5(253), Y5(254), Y5(255), Y5(256), Y5(257), Y5(258)
     +    /    31.5E0, 13.9E0,  4.4E0, 38.0E0,141.7E0,190.2E0/
      DATA  Y5(259), Y5(260), Y5(261)
     +    /   184.8E0,159.0E0,112.3E0/
C
C     DEFINE CONSTANTS
C
      CALL IPRINT(IPRT)
      LPER = 300
      LFREQ = 300
      LYFFT = 600
C
      NY1 = 100
      NY2 = 50
      NY3 = 50
      NY4 = 50
      NY5 = 261
      NY6 = 100
C
      NK = 3
      KMD(1) = 8
      KMD(2) = 8
      KMD(3) = 8
C
      TAPERP = 0.10
C
      NFFT = 514
      IEXTND = 0
      NPRT = -1
C
      ILOG = 1
C
C     WRITE HEADER
C
      WRITE(IPRT, 1000)
C
C     RUN SIMPLE TEST OF ACF
C
      WRITE(IPRT, 1100)
      CALL ACF (Y1, NY1)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF CCF
C
      WRITE(IPRT, 1200)
      CALL CCF (Y2A, Y2B, NY2)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF UFS
C
      WRITE(IPRT, 1300)
      CALL UFS (Y3, NY3)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF UAS
C
      WRITE(IPRT, 1400)
      CALL UAS (Y4, NY4)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF TAPER
C
      WRITE(IPRT, 1510)
      CALL TAPER (Y5, NY5, TAPERP, YFFT)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF PGMS
C
      WRITE(IPRT, 1520)
      CALL PGMS(YFFT, NY5, NFFT, LYFFT,
     +          IEXTND, NF, PER, LPER, FREQ, LFREQ, NPRT)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF MDFLT
C
      WRITE(IPRT, 1530)
      CALL MDFLT (PER, NF, NK, KMD, PERF, LDSTAK)
      WRITE (IPRT,2000) IERR
C
C     DISPLAY RESULTS OF MDFLT
C
      WRITE(IPRT, 1540)
      CALL PPL (PERF, FREQ, NF, ILOG)
      WRITE (IPRT,2000) IERR
C
C     RUN SIMPLE TEST OF BFS
C
      WRITE(IPRT, 1600)
      CALL BFS (Y6A, Y6B, NY6)
      WRITE (IPRT,2000) IERR
C
      RETURN
C
C     FORMAT STATEMENTS
C
 1000 FORMAT ('1*CH12')
 1100 FORMAT (' SIMPLE TEST OF ACF')
 1200 FORMAT ('1SIMPLE TEST OF CCF')
 1300 FORMAT ('1SIMPLE TEST OF UFS')
 1400 FORMAT ('1SIMPLE TEST OF UAS')
 1510 FORMAT ('1SIMPLE TEST OF TAPER (NO OUTPUT UNLESS ERROR FOUND)')
 1520 FORMAT ('1SIMPLE TEST OF PGMS')
 1530 FORMAT ('1SIMPLE TEST OF MDFLT (NO OUTPUT UNLESS ERROR FOUND)')
 1540 FORMAT ('1DISPLAY RESULTS OF MDFLT')
 1600 FORMAT ('1SIMPLE TEST OF BFS')
 2000 FORMAT (/' THE VALUE OF IERR IS ', I4)
      END
